/**
 * Scripts for Cost & Reports
 *
 * @package CostReports/js
 */

var tbl      = '#cyptable';
var aDefault = '';
var $        = jQuery;
var aColor   = $( 'a' ).css( 'color' );

function checkAll() {

	var radio = $( "input[name='stype']:checked" ).val();

	if ( radio === 'rows' ) {
		$( '#checkall' ).prop( 'checked', false );
	}

	$( tbl + ' tbody tr' ).each(
		function(){
			var check = this.children[0].children[0]['id'];
			if ( radio === 'rows' ) {
				if ( this.style.display === '' ) {
					$( check ).prop( 'checked', true );
				} else {
					$( check ).prop( 'checked', false );
				}
			} else {
				$( check ).prop( 'checked', $( '#checkall' ).prop( 'checked' ) );
			}
		}
	);

}
function cypCheckRows() {

	var is_checked = $( '#checkall' ).prop( 'checked' );

	$( tbl + ' tbody tr' ).each(
		function(){
			var check = this.children[0].children[0]['id'];
			if ( this.style.display === '' ) {
				$( check ).prop( 'checked', is_checked );
			} else {
				$( check ).prop( 'checked', false );
			}
		}
	);
}


function sort( column, type, prefix, table ) {

	$( '#' + table ).tableCalc( 'sortColumn', column, type );
	//casDoSort(column, type, '#'+table);
	
	if ( $( '#' + prefix + column ).hasClass( 'fa-sort' ) ) {
		$( '#' + prefix + column ).removeClass( 'fa-sort' ).addClass( 'fa-sort-up' );
		resetSortClass( column, prefix );
		return;
	}
	if ( $( '#' + prefix + column ).hasClass( 'fa-sort-up' ) ) {
		$( '#' + prefix + column ).removeClass( 'fa-sort-up' ).addClass( 'fa-sort-down' );
		resetSortClass( column, prefix );
		return;
	}
	if ( $( '#' + prefix + column ).hasClass( 'fa-sort-down' ) ) {
		$( '#' + prefix + column ).removeClass( 'fa-sort-down' ).addClass( 'fa-sort-up' );
		resetSortClass( column, prefix );
		return;
	}

	function resetSortClass( column, prefix ){
		for ( var i = 1; i < 13; i++ ) { 
			if ( i != column ) {
				$( '#' + prefix + i ).removeClass( 'fa-sort-down' ).removeClass( 'fa-sort-up' ).addClass( 'fa-sort' );
			}
		}
	}

}

function casDoSort( column, type, table ){

	var switching = true;
	var shouldSwitch;
	var switchcount = 0;
	var i;
	var dir = 'asc';
	var rows;
	var table = jQuery(table +' > tbody')[0];

	while ( switching ) {

		switching = false;
		rows = table.rows;

		for ( i = 0; i < (rows.length - 1); i++ ) {
		
			shouldSwitch = false;
			
			var x = rows[i].cells[column];
			var y = rows[i + 1].cells[column];

			var node_type = x.children[0].nodeName;
			switch(type) {
				case 'number':
					if( node_type.toLowerCase() == 'input' ){
						x = (x.childNodes[1].value == '' ) ? 0 : parseFloat(x.childNodes[1].value.replace(/[^0-9.-]/g, ''));
						y = (y.childNodes[1].value == '' ) ? 0 : parseFloat(y.childNodes[1].value.replace(/[^0-9.-]/g, ''));
					} else {
						x = ( undefined !== x.innerText ) ? x.innerText.replace( /[^0-9.-]/g, '' ) : '';
						y = ( undefined !== y.innerText ) ? y.innerText.replace( /[^0-9.-]/g, '' ) : '';
					}
					break;
				case 'text':
					if( node_type.toLowerCase() == 'input' ){
						x = x.childNodes[1].value.replace(/^\s+|\s+$/g, '');
						y = y.childNodes[1].value.replace(/^\s+|\s+$/g, '');
					} else {
						x = ( undefined !== x.innerText ) ? x.innerText.replace( /^\s+|\s+$/g, '' ) : '';
						y = ( undefined !== y.innerText ) ? y.innerText.replace( /^\s+|\s+$/g, '' ) : '';
					}
					break;
				case 'date':
					if( node_type.toLowerCase() == 'input' ){
						x = (x.childNodes[1].value == '' ) ? new Date(-25920000000) : new Date(x.childNodes[1].value);
						y = (y.childNodes[1].value == '' ) ? new Date(-25920000000) : new Date(y.childNodes[1].value);
					} else {
						x = (x.innerText == '' ) ? new Date( -25920000000 ) : new Date( x.innerText );
						y = (y.innerText == '' ) ? new Date( -25920000000 ) : new Date( y.innerText );
					}
					break;
				case 'percent':
					if( node_type.toLowerCase() == 'input' ){
						x = (x.childNodes[0].value == '' ) ? 0 : parseFloat(x.childNodes[0].value.replace(/%\s/g, ''));
						y = (y.childNodes[0].value == '' ) ? 0 : parseFloat(y.childNodes[0].value.replace(/%\s/g, ''));
					} else {
						x = x.innerText.replace(/%\s/g, '');
                        y = y.innerText.replace(/%\s/g, '');
					}
					break;
			}

			if ( x === y ) {
				continue;
			}

			if ( dir === "asc" ) {
				if ( x > y ) {
					shouldSwitch = true;
					break;
				}
			} else if ( dir === "desc" ) {
				if ( x < y ) {
					shouldSwitch = true;
					break;
				}
			}
		}

		if ( shouldSwitch ) {
			rows[i].parentNode.insertBefore( rows[i + 1], rows[i] );
			switching = true;
			switchcount++;
		} else {
			if (switchcount == 0 && dir == "asc") {
				dir       = "desc";
				switching = true;
			}
		}

	}

}

function deleteRows() {
	
	var confirm_delete = confirm( $( '#msg-confirm-delete' ).val() );

	if ( confirm_delete === true ) {
		var rescount  = 0;
		var count     = 0;
		var nonce_val = $( '#_wpnonce' ).val();
		var json_data = { action: 'cyp_delete_table_rows_data', nonce: nonce_val, rows: [] };

		$( tbl + ' tbody form' ).each(
			function() {
				if ( $( this['id'] ).prop( 'checked' ) ) {
					var frm_data = { id: this['id'].value };
					json_data.rows.push( frm_data );
					count++;
				}
			}
		)

		if ( count > 0 ) {
			$.ajax(
				{
					type: 'POST',
					url: ajaxurl,
					datatype: 'json',
					data: json_data,
					success: function( response ) {
						console.log( response );
						rescount++;
						if (rescount > 0) {
							var ms = ( count >= 100 ) ? 2200 : 500;
							reloadPage( ms );
						}
					},
					error: function( response ){
						console.log( response );
					}
				}
			);
		
			event.preventDefault();
		}
	} else {
		$( '#checkall' ).prop( 'checked', false );
		checkAll();
	}

}

function saveAll() {

	var count         = 0;
	var p_count       = 0;
	var rescount      = 0;
	var nonce_val     = $( '#_wpnonce' ).val();
	var json_data     = { action: 'cyp_update_table_rows_data', nonce: nonce_val, rows: [] };
	var exclude_price = ( $( '#exclude_price_save' ).prop( 'checked' ) === true ) ? true : false;

	$( '#saveall' ).css( 'color', aColor );
	
	$( tbl + ' tbody form' ).each(
		function() {
			if ( $( this['id'] ).prop( 'checked' ) ) {

				var shipping = '';
				if(cyp_shipping_cost === 'yes'){
					shipping = this['shipping_cost'].value;
				}

				var frm_data = { id: this['id'].value,
					stock: this['stock'].value, price: this['price'].value,
					price_new: (exclude_price === true) ? this['price'].value : this['price_new'].value, purchase_price: this['purchase_price'].value, other_cost: this['other_cost'].value,
					name: this['product_name'].value, name_update: this['name_update'].value, cost_of_goods: this['cost_of_goods'].value,
					markup: this['markup'].value, shipping_cost: shipping
				};
				
				json_data.rows.push( frm_data );
				count++;
				if( count === 1 ) {
					jQuery( '#saveall' ).attr( 'disabled', true );
					jQuery( '#saveall_foot' ).attr( 'disabled', true );
				}
				
				if( count === 80 ) {
					sendJson( ajaxurl, json_data );
					json_data.rows = [];
					count = 0;
				}

				if( p_count === 1 ) {
					progressBar('start');
				}
				p_count++;
			} 
		}
	);

	if ( count > 0 ) {

		$( '#saveall' ).css( 'color', aDefault );
		//$( '#checkall' ).prop( 'checked', false );
		//checkAll();

		jQuery.ajax(
			{
				type: 'POST',
				url: ajaxurl,
				datatype: 'json',
				data: json_data,
				success: function( response ) {
					console.log( response );
					rescount++;
					if (rescount > 0) {
						jQuery( '#saveall' ).attr( 'disabled', false );
						jQuery( '#saveall_foot' ).attr( 'disabled', false );
						var ms = ( p_count >= 100 ) ? 3000 : 500;
						reloadPage( ms );
					}
				},
				error: function( response ){
					console.log( response );
					jQuery( '#saveall' ).attr( 'disabled', false );
					jQuery( '#saveall_foot' ).attr( 'disabled', false );
					progressBar('stop');
				}
			}
		);
	}

	event.preventDefault();

};

function sendJson( ajaxurl, json_data ) {

	jQuery.ajax(
		{
			type: 'POST',
			url: ajaxurl,
			datatype: 'json',
			data: json_data,
			success: function( response ) {
				console.log( response );
			},
			error: function( response ){
				console.log( response );
			}
		}
	);

}

function reloadPage( msec ) {

	setTimeout(
		function() {
			location.reload();
		},
		msec
	);

}

function calcChanged( ft ) {

	var tot         = sum_col;
	var is_checkbox = ( this.name == 'id' ) ? true : false;
	var is_inputbox = ( this.type == 'number' || this.type == 'text' ) ? true : false;
	var ftv         = ( ft === true ) ? true : false;

	if ( ! ftv ) {
		if ( is_checkbox ) {
			$( this ).prop( 'checked', this.checked );
		}

		if ( is_inputbox ) {
			this.form['id'].checked = true;
		}
	}

	$( '#saveall' ).css( 'color', aColor );
	
	// Check if single row or all
	if ( ftv === true ) {
		doLoop(ftv);
	} else {
		doCalc( this, true );
	}

	function doLoop(ftv){
		var table = $( tbl + ' tbody tr' );
		table.each( function() {
			var row = this.children[0].children[0].elements[0];
			if ( ftv === true ) {
				doCalc( row, false );
			} else {
				doCalc( row, true );
			}
		});
	}
}


function changeCalcType( calcType, customCalculation ){

	$( tbl ).tableCalc( 'calculate', calcType, customCalculation );
	calcChanged();

};

function doCalc( obj, single = true ) {

	if ( obj !== undefined || obj !== '' ) {

		var cas_markup = default_markup || 0;

		var current   = obj.name;
		var the_form  = obj.form.elements;
		var p_price   = parseFloat( the_form['purchase_price'].value || 0 );
		var o_cost    = parseFloat( the_form['other_cost'].value || 0 );
		var c_o_goods = parseFloat( the_form['cost_of_goods'].value || 0 );
		var markup    = parseFloat( the_form['markup'].value || cas_markup );
		var price     = parseFloat( the_form['price'].value || 0 );
		var n_price   = parseFloat( the_form['price_new'].value || 0 );
		var stock     = parseInt( the_form['stock'].value || 0 ); 
		var shipping  = 0;
		var vat_value = parseFloat( the_form['tax_rate'].value );
		var vat_type  = $( '#current_price_select_type option:selected' ).val();

		if(cyp_shipping_cost === 'yes'){
			shipping = parseFloat( the_form['shipping_cost'].value || 0 );
		}

		var price_changed = false;

		switch ( current ) {
			case 'id':
			case 'cost_of_goods':
				if ( c_o_goods > 0 ) {
					o_cost = parseFloat( c_o_goods - p_price - shipping ).toFixed(2);
					the_form['other_cost'].value = o_cost;
				}
				break;
			case 'price':
			case 'price_new':
				if(current === 'price'){
					n_price = parseFloat( price / ( 1 + (vat_value / 100) ) ).toFixed(2);
				}
				//Use this new price
				price_changed = true;
				markup        = ( ( n_price / c_o_goods ) * 100 ) || 0;
				break;
			default:
				c_o_goods = parseFloat( p_price + o_cost + shipping ).toFixed(2);
				the_form['cost_of_goods'].value = c_o_goods;
				break;
		}

		var stock_value_cost = ( c_o_goods * stock ) || 0;
		var sales_value      = ( price * stock ) || 0;
		var margin_value     = ( sales_value - stock_value_cost ) || 0;

		// New price
		if ( ! price_changed ) {
			n_price = ( c_o_goods * markup / 100 ) || 0;
		}

		// If new price not equal price 
		if ( 'id' !== current && n_price > 0 && n_price !== price ) { //
			the_form['price_new'].style.background = 'cornsilk';
			the_form['margin'].style.background    = 'cornsilk';
			//Use new price for sales value
			sales_value  = ( n_price * stock ) || 0;
			margin_value = ( sales_value - stock_value_cost ) || 0;
			
		} else {
			the_form['price_new'].style.background = 'inherit';
			the_form['margin'].style.background    = '#eee';
		}
		
		// If negative margin
		if ( margin_value < 0 ) {
			the_form['margin'].style.color = 'red';
		} else {
			the_form['margin'].style.color = 'inherit';
		}

		if ( o_cost < 0 ) {
			the_form['other_cost'].style.color = 'red';
		} else {
			the_form['other_cost'].style.color = 'inherit';
		}

		// Write all values
		the_form['price_new'].value        = parseFloat( n_price ).toFixed(2);
		the_form['price'].value            = parseFloat( price ).toFixed(2);
		the_form['stock-value-cost'].value = parseFloat( stock_value_cost ).toFixed(2);
		the_form['sales-value'].value      = parseFloat( sales_value ).toFixed(2);
		the_form['margin'].value           = parseFloat( margin_value ).toFixed(2);
		the_form['markup'].value           = (markup !== Infinity) ? parseFloat( markup ).toFixed(2) : '';
		the_form['purchase_price'].value   = parseFloat( p_price ).toFixed(2);
		the_form['other_cost'].value       = parseFloat( o_cost ).toFixed(2);
		
		if(cyp_shipping_cost === 'yes'){
			the_form['shipping_cost'].value = parseFloat( shipping ).toFixed(2);
		}

		// Let user know if differences
		if ( the_form['price_new'].value !== the_form['price'].value ) {
			the_form['price_new'].style.background = 'cornsilk';
		}

		sumarizeTotals( single );

		the_form['stock-value-cost'].value = ( the_form['cost_of_goods'].value > 0 && the_form['stock'].value > 0 ) ? parseFloat( the_form['cost_of_goods'].value * parseInt( the_form['stock'].value ) ).toFixed(2) : 0;
		
		//INC VAT
		if ( 'price' !== current && vat_type === 'inc_vat' || vat_type === 'cur_inc_vat' ) {
			the_form['price'].value = parseFloat( price * ( 1 + ( vat_value / 100 ) ) || 0 ).toFixed(2) || 0;
			
			//Value at cost
			the_form['stock-value-cost'].value = parseFloat( the_form['stock-value-cost'].value * ( 1 + ( vat_value / 100 ) || 0 )).toFixed(2) || 0;

			//Update retail value
			the_form['sales-value'].value = parseFloat( price * stock ).toFixed(2) || 0;

			//Profit
			the_form['margin'].value = parseFloat( the_form['sales-value'].value - the_form['stock-value-cost'].value ).toFixed(2) || 0;
		}
	}
}

function sumarizeTotals( is_single ) {

	if ( is_single ) {
		//Get sums
		if ( $( tbl + ' tbody tr' ).length > 0 ) {
			var table            = $( tbl + ' tbody tr' );
			var tot_stock        = 0;
			var tot_stock_cost   = 0;
			var tot_sales_value  = 0;
			var tot_margin_value = 0;

			table.each( function() {
				var is_visible   = this.style.display;
				var frm          = this.children[0].children[0];
				var frm_elements = frm.elements;
			
				if ( '' === is_visible ) {
					tot_stock         += parseInt( frm_elements['stock'].value || 0 );
					tot_stock_cost    += parseFloat( frm_elements['stock-value-cost'].value || 0 );
					tot_sales_value   += parseFloat( frm_elements['sales-value'].value || 0 );
					tot_margin_value  += parseFloat( frm_elements['margin'].value || 0 );
				}
			});
			//Totals
			$( '#tbl-total-s' ).text( tot_stock );
			$( '#tbl-total-sc' ).text( tot_stock_cost.toFixed(2) );
			$( '#tbl-total-sv' ).text( tot_sales_value.toFixed(2) );
			$( '#tbl-total-m' ).text( tot_margin_value.toFixed(2) );
			
		}
	} else {
		//if shipping cost column is present
		if(cyp_shipping_cost === 'yes'){
			var stock = parseFloat( $( tbl ).tableCalc( 'getSum', 9 ) ).toFixed( 0 );
			$( '#tbl-total-s' ).text( stock );
			$( '#tbl-total-sc' ).text( $( tbl ).tableCalc( 'getSum', 10 ) );
			$( '#tbl-total-sv' ).text( $( tbl ).tableCalc( 'getSum', 11 ) );
			$( '#tbl-total-m' ).text( $( tbl ).tableCalc( 'getSum', 12 ) );
		} else {
			var stock = parseFloat( $( tbl ).tableCalc( 'getSum', 8 ) ).toFixed( 0 );
			$( '#tbl-total-s' ).text( stock );
			$( '#tbl-total-sc' ).text( $( tbl ).tableCalc( 'getSum', 9 ) );
			$( '#tbl-total-sv' ).text( $( tbl ).tableCalc( 'getSum', 10 ) );
			$( '#tbl-total-m' ).text( $( tbl ).tableCalc( 'getSum', 11 ) );
		}
	}

}


function calcSpecial( i, out, id ) {

	var sign    = '+';
	var in_val  = Number( $( '#' + id ).val() );
	var in_type = $( '#' + id + '_type option:selected' ).val();

	var calctype = '';

	switch ( in_type ) {
		case '0':
			break;
		case 'up_p':
			sign     = '+';
			calctype = 'percent';
			break;
		case 'up_n':
			sign     = '+';
			calctype = 'number';
			break;
		case 'down_p':
			sign     = '-';
			calctype = 'percent';
			break;
		case 'down_n':
			sign     = '-';
			calctype = 'number';
			break;
		case 'fix_n':
			sign     = '=';
			calctype = 'number';
			break;
		case 'round_up':
			sign     = 'u';
			calctype = 'round';
			break;
		case 'round_down':
			sign     = 'd';
			calctype = 'round';
			break;
		case 'round_two':
			sign     = 't';
			calctype = 'round';
			break;
		case 'copy_purchase':
			sign     = 'cpu';
			calctype = 'copy';
			break;
		case 'copy_price':
			sign     = 'cp';
			calctype = 'copy';
			break;
		case 'percent_purchase':
			sign     = 'ppp';
			calctype = 'percent';
			break;
		case 'purchase_plus_percent':
			sign     = 'ppp+';
			calctype = 'percent';
			break;
	}

	$( '#' + id ).val( '' );
	$( '#' + id + '_type' ).val( '0' );

	var percent = 1.0;
	var formula = '';
	if ( sign === '+' ) {
		percent = percent + in_val / 100;
		formula = '(0:' + i + '*' + percent + ')==0:' + out + '';
	} else if ( sign === '-' ) {
		percent = percent - in_val / 100;
		formula = '(0:' + i + '*' + percent + ')==0:' + out + '';
	} else if ( sign === 'ppp' ) {
		percent = in_val / 100;
		formula = '(0:' + 0 + '*' + percent + ')==0:' + out + '';
	} else if ( sign === 'ppp+' ) {
		percent = percent + in_val / 100;
		formula = '(0:' + 0 + '*' + percent + ')==0:' + out + '';
	}
	
	if ( calctype === 'number' ) {
		if ( sign === '=' ) {
			var c = out;
			formula = '(0:' + i + '*' + 0 + '+' + in_val + ')==0:' + out + '';
		} else {
			formula = '(0:' + i + sign + in_val + ')==0:' + out + '';
		}
	}

	if ( calctype === 'round' ) {
		roundNumbers( out, sign );
	} else if ( calctype === 'copy' ) {
		copyFields( out, sign );
	} else {
		$( tbl ).tableCalc( 'calculate', 'c', formula );
	}

	var table = $( tbl + ' tbody tr' );
	table.each( function() {
		var row = this.children[out].children[0];
		if( this.style.display === '') {
			doCalc( row, false );
		}
	});
	
	$( '#saveall' ).css( 'color', aColor );
	$( '#checkall' ).prop( 'checked', true );

	checkAll();

};

function roundNumbers( column, sign ) {

	var table = $( tbl + ' tbody tr' );

	table.each(
		function() {
			var rValue = this.children[column].children[0].value;
			var rOut   = 0;
			switch ( sign ) {
				case 'd':
					rOut = Number(Math.floor(rValue)).toFixed(2);
					break;
				case 'u':
					rOut = Number(Math.ceil(rValue)).toFixed(2);
					break;
				case 't':
					rOut = Number(rValue).toFixed(1);
					break;
			}

			var newValue = Number(rOut).toFixed(2);
			if ( Number(rOut) === 0 ) {
				newValue = '';
			}
			
			this.children[column].children[0].value = newValue;
		}
	)
}

function copyFields( column, sign ) {
	
	var table = $( tbl + ' tbody tr' );
	var cpf   = 6;

	if(cyp_shipping_cost === 'yes'){
		cpf = 7;
	}

	table.each(
		function() {
			switch (sign){
				case 'cp':
					this.children[column].children[0].value = this.children[cpf].children[3].value;
					break;
				case 'cpu':
					this.children[column].children[0].value = this.children[2].children[0].value;
					break;
			}
		}
	)

}

function reportFilter( tab ) {
	
	if ( 'customers' === tab ) {
		tbl_rep = '#table-customers';
	}

	var input = $( '#report_search' ).val();
	var table = $( tbl_rep + ' tbody tr' );
	var arr   = [];

	input = input.toLowerCase().replace( ',', '' );
	arr   = input.split( ' ' );

	table.each(
		function() {
			var order_id = this.children[0].innerText;
			var txt1     = this.children[1].innerText;
			var txt2     = this.children[2].innerText;
			var txt3     = this.children[3].innerText;
			var txt4     = this.children[4].innerText;
			var txt5     = this.children[5].innerText;
			if (order_id){
				var order_txt = order_id;
				var count     = 0;
				for( var i = 0; i < arr.length; i++ ) {
					if ( order_txt.match( arr[i] ) || 
						txt1.toLowerCase().match( arr[i] ) ||
						txt2.toLowerCase().match( arr[i] ) ||
						txt3.toLowerCase().match( arr[i] ) ||
						txt4.toLowerCase().match( arr[i] ) ||
						txt5.toLowerCase().match( arr[i] )
						) {
						count++;
					} 
				}
				if ( count === arr.length ) {
					this.style.display = '';
					this.attributes[1].value = '';//export
				} else {
					this.style.display = 'none';
					this.attributes[1].value = 'true';//export
				}
			}
		}
	);
	
	//Calculate if products
	if ( tab === 'products' ) {
		reportCalc();
	}

	//Sum if customers
	if ( tab === 'customers' ) {
		cyp_rep_customers_set();
	}

	//Sum if orders (tab)
	if ( tab === 'orders' ) {
		cyp_rep_orders_set();
	}
	
}

function rowSearch(){

	var input = $( '#product_search' ).val();
	var table = $( tbl + ' tbody tr' );
	var radio = $( "input[name='stype']:checked" ).val();
	var arr   = [];

	if ( radio === 'rows' ) {
		if ( input.length > 0 ) {
			input = input.toLowerCase();
			arr   = input.split( ' ' );
		}
		var tot_stock        = 0;
		var tot_stock_cost   = 0;
		var tot_sales_value  = 0;
		var tot_margin_value = 0;

		table.each(
			function() {
				var textValue    = this.children[1].children[0].children[0].value;
				var sku          = this.children[1].children[0].children[2].children[1].innerText;
				var frm_elements = this.children[0].children[0].elements;
				if (textValue){
					var txt = textValue.toLowerCase();
					sku     = ( sku.length > 5 ) ? sku.toLowerCase().split(':')[1] : ''; 
					var count = 0;
					for( var i = 0; i < arr.length; i++ ) {
						if ( txt.match( arr[i] ) || sku.match( arr[i] ) ) {
							count++;
						} 
					}
					if( count === arr.length ) {
						this.style.display = '';
						tot_stock         += parseInt( frm_elements['stock'].value || 0 );
						tot_stock_cost    += parseFloat( frm_elements['stock-value-cost'].value || 0 );
						tot_sales_value   += parseFloat( frm_elements['sales-value'].value || 0 );
						tot_margin_value  += parseFloat( frm_elements['margin'].value || 0 );
					} else {
						this.style.display = 'none';
					}
				}
			}
		)
		//Totals
		$( '#tbl-total-s' ).text( tot_stock );
		$( '#tbl-total-sc' ).text( tot_stock_cost.toFixed(2) );
		$( '#tbl-total-sv' ).text( tot_sales_value.toFixed(2) );
		$( '#tbl-total-m' ).text( tot_margin_value.toFixed(2) );

		//Count rows
		cypCountProducts(tbl);
	
	} 
}

function beforeDownloadSubmit(){

	var rows = $('#cyptable tbody tr:visible');
	var ids  = [];
	rows.each( function() {
		ids.push(this.children[0].id);
	});

	$('#download_ids').val(ids);

}

function radioChange() {

	var radio = $( "input[name='stype']:checked" ).val();

	if ( radio === 'rows' ) {
		$( 'form #btnsearch' ).attr( 'disabled', true );
	} else {
		$( 'form #btnsearch' ).attr( 'disabled', false );
	}

}

function sortTable( table, order ) {
	
	var sort  = 'asc';
	var tbody = table.find( 'tbody' );
	if ( order !== 'asc' ) {
		sort = '';
	}

    tbody.find('tr').sort(function(a, b) {
		var a1 = a.children[1].children[0].value;
		var b1 = b.children[1].children[0].value;
	
        if ( sort === 'asc' ) {
			return a1.localeCompare(b1);
        } else {
			return b1.localeCompare(a1);
        }
	}).appendTo(tbody);
	
}

function clearCalc() {
	
	$( tbl + ' tbody tr' ).each(
		function() {
			var is_visible   = this.style.display;
			var frm          = this.children[0].children[0];
			var frm_elements = frm.elements;

			if ( '' === is_visible ) {
				if ( frm_elements['purchase_price'].value.length > 0 || 
					frm_elements['other_cost'].value.length > 0 || 
					frm_elements['cost_of_goods'].value.length > 0 || 
					frm_elements['markup'].value.length > 0 ) {

						frm_elements['purchase_price'].value = '';
						frm_elements['other_cost'].value     = '';
						frm_elements['cost_of_goods'].value  = '';
						frm_elements['markup'].value         = '';
						frm_elements['price_new'].value      = '';
						if(cyp_shipping_cost === 'yes'){
							frm_elements['shipping_cost'].value = '';
						}
						$( frm_elements['id'] ).prop( 'checked', true );
						is_checked = true;

				} else {
					frm_elements['purchase_price'].value = frm_elements['purchase_price'].defaultValue;
					frm_elements['other_cost'].value     = frm_elements['other_cost'].defaultValue;
					frm_elements['cost_of_goods'].value  = frm_elements['cost_of_goods'].defaultValue;
					frm_elements['markup'].value         = frm_elements['markup'].defaultValue;
					if(cyp_shipping_cost === 'yes'){
						frm_elements['shipping_cost'].value = frm_elements['shipping_cost'].defaultValue;
					}
					doCalc(frm_elements['cost_of_goods']);
					$( frm_elements['id'] ).prop( 'checked', false );
				}
			}
		}
	)
	
}

function removeNull() {
	
	var obj = document.activeElement.value;
	if( Number(obj) === 0 ) {
		document.activeElement.value = '';
	}

}

function progressBar( option ) {
	
	if (option === 'start'){
		$('#cyp-saving').removeClass('cyp-saving').addClass('cyp-saving-show');
		var v = 0;
		
		setInterval(
			function() {
				if ( v > 100) {
					v = 0;
				}
				$('#pbar-saving').val(v);
				v += 5;
			},
			50
		);

	} else {
		$('#cyp-saving').removeClass('cyp-saving-show').addClass('cyp-saving');
	}

}

function reportCalc() {

	var qty        = 0; 
	var gross_sale = 0; 
	var profit     = 0;
	var percent    = 0;
	var arr        = [];
	var row_search = false;

	$( tbl_rep + ' tbody tr' ).each(
		function() {

			if ( this.style.display !== '' ) {
				row_search = true;
				return;
			}

			var row    = this.children;
			var cat    = row[1].innerText;
			var prod   = row[2].innerText;
			var sku    = row[3].innerText;
			var items  = parseInt( row[4].innerText ) || 0;
			var tot    = parseFloat( row[6].innerText.replace(',','.') ) || 0;
			var p      = parseFloat( row[7].innerText.replace(',','.') ) || 0;
			var pc     = parseFloat( row[8].innerText.replace(',','.') ) || 0;

			qty        += items;
			gross_sale += tot;
			profit     += p;
		
			var obj_row = { sku_id: sku, category: cat, product: prod, count: items, sale: tot, profit: p, pcent: pc };

			if( arr.length > 0 ) {
				var index = arr.findIndex(function(x) { return x.sku_id == sku });
				if (index !== -1){
					arr[index].count   += items;
					arr[index].sale    += tot;
					arr[index].profit  += p;
				} else {
					arr.push(obj_row);
				} 
			} else {
				arr.push(obj_row);
			}
		}
	);

	if ( gross_sale > 0 && profit > 0 ) {
		percent = parseFloat( profit * 100 / gross_sale ).toFixed(2);
	}

	$( '#pr5,#pr_sum_items' ).text( qty );
	$( '#pr7,#pr_gross_sales' ).text( parseFloat( gross_sale ).toFixed(2) );
	$( '#pr8,#pr_total_profit' ).text( parseFloat( profit ).toFixed(2) );
	$( '#pr_profit_percent' ).text( percent + '%');

 	var arr2 = arr.sort(function (a, b) {
		return a.count - b.count;
	});
	
	var min  = arr2[0];
	var max  = arr2[arr2.length - 1];
	var max2 = arr2[arr2.length - 2];

	//#1
	if(max !== undefined){
		$( '#pr_top_product' ).text( max.product );
		$( '#pr_top_product_sku' ).text( max.sku_id );
		$( '#pr_top1_cat' ).text( max.category );
		$( '#pr_top1_sales' ).text( parseFloat( max.sale ).toFixed(2) );
		$( '#pr_top1_turnover' ).text( parseFloat( max.sale * 100 / gross_sale ).toFixed(2)  + '%' );
		$( '#pr_top1_turnover_qty' ).text( parseFloat( max.count * 100 / qty ).toFixed(2)  + '%' );
		$( '#pr_top1_item_qty' ).text( max.count );
		$( '#pr_top1_item_profit' ).text( parseFloat( max.profit * 100 / max.sale ).toFixed(2) + '%' );
	}
	//#2
	if(max2 !== undefined){
		$( '#pr_top2_product' ).text( max2.product );
		$( '#pr_top2_product_sku' ).text( max2.sku_id );
		$( '#pr_top2_cat' ).text( max2.category );
		$( '#pr_top2_sales' ).text( parseFloat( max2.sale ).toFixed(2) );
		$( '#pr_top2_turnover' ).text( parseFloat( max2.sale * 100 / gross_sale ).toFixed(2) + '%' );
		$( '#pr_top2_turnover_qty' ).text( parseFloat( max2.count * 100 / qty ).toFixed(2)  + '%' );
		$( '#pr_top2_item_qty' ).text( max2.count );
		$( '#pr_top2_item_profit' ).text( parseFloat( max2.profit * 100 / max2.sale ).toFixed(2) + '%' );
	}
	
	var arr3 = arr.sort(function (a, b) {
		return a.pcent - b.pcent;
	});

	var tp1 = arr3[arr3.length - 1];
	var tp2 = arr3[arr3.length - 2];

	//#1 profit
	if(tp1 !== undefined){
		$( '#pr_top_product_pro' ).text( tp1.product );
		$( '#pr_top_product_sku_pro' ).text( tp1.sku_id );
		$( '#pr_top1_cat_pro' ).text( tp1.category );
		$( '#pr_top1_sales_pro' ).text( parseFloat( tp1.sale ).toFixed(2) );
		$( '#pr_top1_pro_turnover' ).text( parseFloat( tp1.sale * 100 / gross_sale ).toFixed(2) + '%' );
		$( '#pr_top1_pro_turnover_qty' ).text( parseFloat( tp1.count * 100 / qty ).toFixed(2)  + '%' );
		$( '#pr_top1_item_qty_pro' ).text( tp1.count );
		$( '#pr_top1_item_profit_pro' ).text( parseFloat( tp1.profit * 100 / tp1.sale ).toFixed(2) + '%' );
	}
	//#2 profit
	if(tp2 !== undefined){
		$( '#pr_top2_product_pro' ).text( tp2.product );
		$( '#pr_top2_product_sku_pro' ).text( tp2.sku_id );
		$( '#pr_top2_cat_pro' ).text( tp2.category );
		$( '#pr_top2_sales_pro' ).text( parseFloat( tp2.sale ).toFixed(2) );
		$( '#pr_top2_pro_turnover' ).text( parseFloat( tp2.sale * 100 / gross_sale ).toFixed(2) + '%' );
		$( '#pr_top2_pro_turnover_qty' ).text( parseFloat( tp2.count * 100 / qty ).toFixed(2)  + '%' );
		$( '#pr_top2_item_qty_pro' ).text( tp2.count );
		$( '#pr_top2_item_profit_pro' ).text( parseFloat( tp2.profit * 100 / tp2.sale ).toFixed(2) + '%' );
	}

	//Averages
	var q1 = 0, pri1 = 0, pro1 = 0, per1 = 0;
	var rows_count = 0;
	
	$(tbl_rep + ' tbody tr').each(function() {
		if (this.style.display === ''){
			rows_count++;
			pri1 += parseFloat( this.children[5].innerText.replace(',','.') );
			per1 += parseFloat( this.children[8].innerText.replace(',','.') );
		}
	});

	for( var i = 0; i < arr.length; i++ ) {
		var obj = arr[i];
		q1   += parseInt( obj.count );
		pro1 += parseFloat( obj.profit );
	}

	$('#avr_qty').text((q1 / rows_count).toFixed(0));
	$('#avr_price').text((pri1 / rows_count).toFixed(2));
	$('#avr_sale').text((gross_sale / rows_count).toFixed(2));
	$('#avr_profit').text((pro1 / rows_count).toFixed(2));
	$('#avr_percent').text((per1 / rows_count).toFixed(2));
	
  
}

//Editor home - footer
function get_footer_totals() {
	
	var tot_stock  = 0;
	var tot_vac    = 0;
	var tot_rv     = 0;
	var tot_profit = 0;

	$( tbl + ' tbody form' ).each(
		function() {
			tot_stock  += parseInt( this['stock'].value ) || 0;
			tot_vac    += parseFloat( this['stock-value-cost'].value ) || 0; 
			tot_rv     += parseFloat( this['sales-value'].value ) || 0; 
			tot_profit += parseFloat( this['margin'].value ) || 0; 
		}
	);

	$( '#tbl-total-s' ).text( tot_stock );
	$( '#tbl-total-sc' ).text( tot_vac.toFixed(2) );
	$( '#tbl-total-sv' ).text( tot_rv.toFixed(2) );
	$( '#tbl-total-m' ).text( tot_profit.toFixed(2) );
	
}

function cypCountProducts( cyp_table ) {
	
	var tbl = $( 'table' ).attr('id');

	if ('table-report' === tbl) {
		return;
	}

	var table    = $( cyp_table + ' tbody tr' );
	var prod     = 0;
	var prod_var = 0;

	table.each(
		function() {
			if ( this.style.display === '' ) {
				var td = this.children[1].children[0].children[0].type;
				if ( td === 'hidden' ) {
					prod_var++;
				} else {
					prod++;
				}
			}
		}
	);

	$('#cyp-prod-count').text( cyp_object.products + ': ' + prod + ' | ' + cyp_object.variations + ': ' + prod_var );
}

function cyp_rep_orders_set() {

	var items  = 0;
	var profit = 0;
	var cogs   = 0;
	var net    = 0;
	var tax    = 0;
	var ship   = 0;

	$('#table-report tbody tr:visible').each( function() {
		
		items  += ( this.children[5].innerText.length > 0 ) ? parseFloat( this.children[5].innerText ) : 0;
		profit += ( this.children[6].innerText.length > 0 ) ? parseFloat( this.children[6].innerText ) : 0;
		cogs   += ( this.children[8].innerText.length > 0 ) ? parseFloat( this.children[8].innerText ) : 0;
		net    += ( this.children[9].innerText.length > 0 ) ? parseFloat( this.children[9].innerText ) : 0;
		tax    += ( this.children[10].innerText.length > 0 ) ? parseFloat( this.children[10].innerText ) : 0;
		ship   += ( this.children[11].innerText.length > 0 ) ? parseFloat( this.children[11].innerText ) : 0;
	});

	$('#rep-ord-items').text(items);
	$('#rep-ord-profit').text(profit.toFixed(2));
	$('#rep-ord-cogs').text(cogs.toFixed(2));
	$('#rep-ord-net').text(net.toFixed(2));
	$('#rep-ord-tax').text(tax.toFixed(2));
	$('#rep-ord-ship').text(ship.toFixed(2));
}

function cyp_rep_customers_set() {

	var shipping_tot = 0;
	var total        = 0;
	var tax          = 0;
	var items        = 0;

	$('#table-customers tbody tr').each( function() {
		if ( this.style.display === '' ) {
			shipping_tot += ( this.children[7].innerText.length > 0 ) ? parseFloat( this.children[7].innerText ) : 0;
			total        += ( this.children[8].innerText.length > 0 ) ? parseFloat( this.children[8].innerText ) : 0;
			tax          += ( this.children[9].innerText.length > 0 ) ? parseFloat( this.children[9].innerText ) : 0;
			items        += ( this.children[10].innerText.length > 0 ) ? parseFloat( this.children[10].innerText ) : 0;
		}
	});

	$('#cf7').text(shipping_tot.toFixed(2));
	$('#cf8').text(total.toFixed(2));
	$('#cf9').text(tax.toFixed(2));
	$('#cf10').text(items);

}

function cyp_check_new_orders() {
	
	var tbl = $( 'table' ).attr('id');

	if ('table-report' !== tbl) {
		return;
	}

	var time = 10000;

	setInterval(
		function() {

			var is_auto   = $( '#cyp-auto-orders' ).prop('checked');
			var auto_val  = $( '#cyp-auto-orders-value' ).val();
			var nonce_val = $( '#_wpnonce' ).val();
			var json_data = { action: 'cyp_check_for_new_orders', nonce: nonce_val, orders: auto_val, refresh: is_auto.toString() };
		
			jQuery.ajax(
				{
					type: 'POST',
					url: ajaxurl,
					datatype: 'json',
					data: json_data,
					success: function( response ) {
						//console.log( response );
						if (parseInt(response) > parseInt(auto_val)) {
							if ( is_auto ) {
								reloadPage( 50 );
							} else {
								$( '#cyp-auto-orders-value' ).val(response);
								$( '#cyp-auto-orders-value-out' ).text(response);
							}
						}
					},
					error: function( response ){
						console.log( response );
					}
				}
			);
		},
		time
	);


}

function cyp_export_html_table( view ) {

	const dateTime = new Date();
	const day      = dateTime.getDate();
	const month    = dateTime.getMonth() + 1;
	const year     = dateTime.getFullYear();
	const hour     = dateTime.getHours();
	const minute   = dateTime.getMinutes();
	const postfix  = `${day}.${month}.${year}_${hour}.${minute}`;

	var t     = ( 'customers' === view ) ? 'table-customers' : 'table-report';
	let table = document.getElementById(t);
	TableToExcel.convert(table, { 
		name: postfix +'_export.xlsx', 
		sheet: {
			name: 'Cost & Reports - report'
		}
	});

}

function cyp_export_home_table() {

	const dateTime = new Date();
	const day      = dateTime.getDate();
	const month    = dateTime.getMonth() + 1;
	const year     = dateTime.getFullYear();
	const hour     = dateTime.getHours();
	const minute   = dateTime.getMinutes();
	const postfix  = `${day}.${month}.${year}_${hour}.${minute}`;

	let head_row  = $('#cyptable thead tr');
	let exp_table = '<table id="cyptable-exp" style="display:none;"><thead><tr>';

	var head   = head_row[0].children;
	exp_table += '<th></th>';
	exp_table += '<th>' + head[1].children[0].innerText + '</th>';
	exp_table += '<th>' + head[2].children[0].innerText + '</th>';
	exp_table += '<th>' + head[3].children[0].innerText + '</th>';
	exp_table += '<th>' + head[4].children[0].innerText + '</th>';
	exp_table += '<th>' + head[5].children[0].innerText + '</th>';
	exp_table += '<th>' + head[6].children[0].innerText + '</th>';
	exp_table += '<th>' + head[7].children[0].innerText + '</th>';
	exp_table += '<th>' + head[8].children[0].innerText + '</th>';
	exp_table += '<th>' + head[9].children[0].innerText + '</th>';
	exp_table += '<th>' + head[10].children[0].innerText + '</th>';
	exp_table += '<th>' + head[11].children[0].innerText + '</th>';
	
	exp_table += '</tr></thead><tbody>';

	$('#cyptable tbody tr:visible').each( function() {
		var frm = this.children[0].children[0];
		exp_table += '<tr>';
		exp_table += '<td>'+ frm['id'].value +'</td>';
		exp_table += '<td>'+ frm['product_name'].value +'</td>';
		exp_table += '<td>'+ frm['purchase_price'].value +'</td>';
		exp_table += '<td>'+ frm['other_cost'].value +'</td>';
		exp_table += '<td>'+ frm['cost_of_goods'].value +'</td>';
		exp_table += '<td>'+ frm['markup'].value +'</td>';
		exp_table += '<td>'+ frm['price'].value +'</td>';
		exp_table += '<td>'+ frm['price_new'].value +'</td>';
		exp_table += '<td>'+ frm['stock'].value +'</td>';
		exp_table += '<td>'+ frm['stock-value-cost'].value +'</td>';
		exp_table += '<td>'+ frm['sales-value'].value +'</td>';
		exp_table += '<td>'+ frm['margin'].value +'</td>';
		exp_table += '</tr>';
	});

	exp_table += '</tbody></table>';
	$('.cyp-main').after(exp_table);
	
	let table = document.getElementById('cyptable-exp');
	TableToExcel.convert(table, { 
		name: postfix +'_export.xlsx', 
		sheet: {
			name: 'Cost & Reports - home table'
		}
	});

	//Remove from DOM
	$('#cyptable-exp').remove();

}

function cyp_change_vat_price(obj) {

	var in_type = $( '#current_price_select_type option:selected' ).val();
	var table   = $( '#cyptable tbody form' );
	
	table.each( function() {
		
		var use_vat = false;

		switch( in_type ) {
			case '0':
				this['price'].value = this['price'].defaultValue;
				this['price'].setAttribute('readonly','readonly');
				break;
			case 'inc_vat':
				this['price'].value = parseFloat( this['price_inc_vat'].value ).toFixed(2);
				this['price'].removeAttribute('readonly');
				use_vat = true;
				break;
			case 'ex_vat':
				this['price'].value = parseFloat( this['price_ex_vat'].value ).toFixed(2);
				this['price'].setAttribute('readonly','readonly');
				break;
			case 'cur_ex_vat':
				this['price'].value = parseFloat( this['cur_price_ex_vat'].value ).toFixed(2);
				this['price'].setAttribute('readonly','readonly');
				break;
			case 'cur_inc_vat':
				this['price'].value = parseFloat( this['cur_price_inc_vat'].value ).toFixed(2);
				this['price'].setAttribute('readonly','readonly');
				use_vat = true;
				break;

		}
		//Vat rate
		var tax_rate = parseFloat( 1 + this['tax_rate'].value / 100 ).toFixed(2);

		//Update retail value
		this['sales-value'].value      = (this['price'].value > 0 && this['stock'].value > 0) ? parseFloat( this['price'].value * parseInt( this['stock'].value ) ).toFixed(2) : 0;
		this['stock-value-cost'].value = (this['cost_of_goods'].value > 0 && this['stock'].value > 0) ? parseFloat( this['cost_of_goods'].value * parseInt( this['stock'].value ) ).toFixed(2) : 0;
		
		//Value at cost and VAT colour
		if( use_vat ) {
			this['stock-value-cost'].value = parseFloat( this['stock-value-cost'].value * tax_rate ).toFixed(2) || 0;
			this['stock-value-cost'].style.color = 'navy';
			this['sales-value'].style.color      = 'navy';
			this['margin'].style.color           = 'navy';
			this['price'].style.color            = 'navy';
		} else {
			this['stock-value-cost'].style.color = 'black';
			this['sales-value'].style.color      = 'black';
			this['margin'].style.color           = 'black';
			this['price'].style.color            = 'black';
		}

		//Profit
		this['margin'].value = parseFloat( this['sales-value'].value - this['stock-value-cost'].value ).toFixed(2) || 0;

		get_footer_totals();

	});
}

function cyp_show_hide_info() {

	var is_checked = $('#cyp-chk-hide-info').prop('checked');
	
	if ( ! is_checked ) {
		$('table ul').removeClass('cyp-ul-info-hide').addClass('cyp-ul-info');
	} else {
		$('table ul').removeClass('cyp-ul-info').addClass('cyp-ul-info-hide');
	}

}

function cyp_reset_table_values() {

	$( '#cyptable tbody form input[name="id"]:checked' ).each( function () {
		$(this.form)[0].reset();
	});
	calcChanged(true);
	get_footer_totals();

}


