<?php
/**
 * Cost & Reports
 *
 * @package CostReports/includes
 */

defined( 'ABSPATH' ) || exit;


class Cyp_Functions {

	/**
	 * Array for products
	 */
	public $json_products;

	/**
	 * Constructor
	 */
	public function __construct() {

		$this->json_products = array( 
			'rows'      => array(), 
			'total'     => 0, 
			'num-pages' => 0,
		);

	}
	
	/**
	 * Get category slug
	 *
	 * @param var $id int.
	 */
	public function cyp_get_category_slug( $id ) {
		$term = get_term_by( 'id', $id, 'product_cat', 'ARRAY_A' );
		return $term['slug'];
	}

	/**
	 * Update product
	 *
	 * @param var $post object.
	 */
	public function cyp_update_product( $post ) {

		if ( ! isset( $post['id'] ) ) {
			die();
		}

		$id             = sanitize_text_field( $post['id'] );
		$price          = sanitize_text_field( $post['price'] );
		$purchase_price = sanitize_text_field( $post['purchase_price'] );
		$stock          = sanitize_text_field( $post['stock'] );
		$price_new      = sanitize_text_field( $post['price_new'] );
		$other_cost     = sanitize_text_field( $post['other_cost'] );
		$shipping_cost  = sanitize_text_field( $post['shipping_cost'] );
		$cost_of_goods  = sanitize_text_field( $post['cost_of_goods'] );
		$markup         = sanitize_text_field( $post['markup'] );
		$name           = sanitize_text_field( $post['name'] );
		$update_name    = sanitize_text_field( $post['name_update'] );
		$product        = wc_get_product( $id );
		$cyp_options    = get_option( 'cyp_options' );
		$cog_field      = ( $cyp_options['cyp_cost_of_goods_field'] ) ? $cyp_options['cyp_cost_of_goods_field'] : '_cost_of_goods';
		$pp_field       = ( $cyp_options['cyp_purchase_price_field'] ) ? $cyp_options['cyp_purchase_price_field'] : '_purchase_price';
		$meta_subscr    = '_subscription_price';
	
		if ( isset( $purchase_price ) ) {
			$product->update_meta_data( $pp_field, $purchase_price );
		}
		if ( isset( $cost_of_goods ) ) {

			//Use for variables if integration with Cost of goods
			if ( $product->is_type( 'variable' ) && '_wc_cog_cost' === $cog_field ) {
				$cog_field = '_wc_cog_cost_variable';
			}

			$product->update_meta_data( $cog_field, $cost_of_goods );
		}
		if ( isset ( $markup ) ) {
			$product->update_meta_data( '_markup_percent', $markup );
		}
		if ( isset ( $other_cost ) ) {
			$product->update_meta_data( '_other_cost', $other_cost );
		}
		if ( isset ( $shipping_cost ) ) {
			$product->update_meta_data( '_cyp_shipping_cost', $shipping_cost );
		}

		
		if ( $price_new > 0 && $price_new !== $price ) {
			if ( 'subscription' === $product->get_type() ) {
				$product->update_meta_data( $meta_subscr, $price_new );
			} else {
				$product->set_price( $price_new );
			}
			$product->set_regular_price( $price_new );
		} else {
			if ( 'subscription' === $product->get_type() ) {
				$product->update_meta_data( $meta_subscr, $price );
			} else {
				$product->set_price( $price );
			}
			$product->set_regular_price( $price );
		}
		
		$product->set_stock_quantity( $stock );

		//Product name
		if ( 'true' === $update_name && strlen( $name ) > 0 ) {
			$product->set_name( $name );
		}
		
		$stock_status = ( strlen( $product->get_stock_status() ) > 0 ) ? $product->get_stock_status() : 'instock';

		//Stock
		if ( strlen( $stock ) > 0 ) {
			$product->set_manage_stock( 'true' );
			$product->set_stock_status( $stock_status );
		} else {
			if ( 'yes' === $cyp_options['cyp_no_stock_management'] ) {
				$product->set_manage_stock( 'false' );
				$product->set_stock_status( $stock_status );
			}
		}

		$product->save();

	}

	/**
	 * Header buttons
	 */
	public function cyp_get_view_buttons() {

		$view     = filter_input( 1, 'view', FILTER_DEFAULT );
		$prod_cat = filter_input( 1, 'product_cat', FILTER_DEFAULT );
		$url      = admin_url( 'admin.php?page=crw&product_cat=' . $prod_cat . '&view=' );
		

		if ( ! isset( $view ) || 'main' === $view ) { 
			?>
			<a type="button" href="#0" name="main-view" class="button-secondary disabled" style="margin-right: 5px;">
				<i class="fas fa-home"></i> <?php esc_attr_e( 'Editor home', 'woo-calculate-your-price' ); ?>
			</a>
			<a type="button" href="<?php echo esc_url( $url . 'rep' ); ?>" name="report-view" class="button-primary" style="margin-right: 5px;">
				<i class="fas fa-chart-line"></i> <?php esc_attr_e( 'Sales reports', 'woo-calculate-your-price' ); ?>
			</a>
			
			<a type="button" href="<?php echo esc_url( admin_url( 'admin.php?page=wc-settings&tab=crw' ) ); ?>" class="button-secondary" id="a-settings" style="margin-right: 5px;"><i class="fas fa-cog"></i></a>
			<form method="post" id="download_form" action="<?php echo esc_attr( admin_url( 'admin-post.php?csv=true&product_cat=' . $prod_cat ) ); ?>" style="margin-right:5px;">
				<input type="hidden" name="action" value="return_csv_file">
				<input type="hidden" id="download_ids" name="download_ids" value="">
				<button type="submit" name="download_csv" class="button-secondary">
				<i class="fas fa-cloud-download-alt"></i> <?php esc_attr_e( 'Download (.csv)', 'woo-calculate-your-price' ); ?>
				</button>
			</form>
			<button class="button-secondary" onclick="cyp_export_home_table();" style="margin-right: 4px;"><i class="fas fa-file-export"></i> <?php esc_attr_e( 'Export table', 'woo-calculate-your-price' ); ?></button>
			<?php do_action( 'cyp_action_cyp_create_link_to_wbte' ); ?>
			<?php
		} elseif ( 'rep' === $view ) {
			?>
			<a type="button" href="<?php echo esc_url( $url . 'main' ); ?>" name="main-view" class="button-secondary" style="margin-right: 5px;">
				<i class="fas fa-home"></i> <?php esc_attr_e( 'Editor home', 'woo-calculate-your-price' ); ?>
			</a>
			<a type="button" href="#0" name="report-view" class="button-primary disabled"  style="margin-right: 5px;">
				<i class="fas fa-chart-line"></i> <?php esc_attr_e( 'Sales reports', 'woo-calculate-your-price' ); ?>
			</a>
			<?php
		}

	}

	/**
	 * Get products
	 */
	public function cyp_get_products() {

		$cyp_options   = get_option( 'cyp_options' );
		$post_per_page = ( $cyp_options['cyp_posts_per_page'] > 0 ) ? $cyp_options['cyp_posts_per_page'] : 150;
		$prod_cat      = ( strlen( filter_input( 1, 'product_cat', FILTER_DEFAULT ) ) > 0 ) ? filter_input( 1, 'product_cat', FILTER_DEFAULT ) : '';
		$prod_search   = filter_input( 1, 'product_search', FILTER_DEFAULT );
		$prod_order    = filter_input( 1, 'order', FILTER_DEFAULT );
		$page_num      = ( strlen( filter_input( 1, 'paged', FILTER_DEFAULT ) ) > 0 ) ? filter_input( 1, 'paged', FILTER_DEFAULT ) : 1;
		$stype         = filter_input( 1, 'stype', FILTER_DEFAULT );
		$is_download   = ( strlen( filter_input( 1, 'csv', FILTER_DEFAULT ) ) > 0 ) ? filter_input( 1, 'csv', FILTER_DEFAULT ) : '';
		$del_transient = false;

		if ( strlen( $prod_search ) > 0 ) {
			$prod_cat      = '';
			$del_transient = true;
		}

		$args = array(
			'orderby' => 'title',
			'order'   => 'ASC',
		);

		$query = new WC_Product_Query( $args );

		if ( isset( $prod_cat ) ) {
			$query->set( 'category', $prod_cat );
			if ( get_transient( 'cyp_cur_category' ) === $prod_cat ) {
				set_transient( 'cyp_cur_category', $prod_cat, 10 * MINUTE_IN_SECONDS  );
			} else {
				$del_transient = true;
				set_transient( 'cyp_cur_category', $prod_cat, 10 * MINUTE_IN_SECONDS  );
			}
		}

		if ( $prod_search ) {
			if ( 'sku' === $stype ) {
				$query->set( 'sku', $prod_search );
			} else {
				$query->set( 's', $prod_search );
			}
			$query->set( 'orderby', 'relevance' );
			$del_transient = true;
		}

		if ( $prod_order ) {
			$query->set( 'order', $prod_order );
		}

		if ( $post_per_page ) {
			$query->set( 'page', $page_num );
			$query->set( 'paginate', true );
			$query->set( 'limit', $post_per_page );
			
			if ( get_transient( 'cyp_json_products' ) && get_transient( 'cyp_json_products' )['page'] !== $page_num ) {
				$del_transient = true;
			}
		}

		if ( 'true' === $is_download ) {
			$query->set( 'limit', -1 );
			$del_transient = true;
		}

		if ( $del_transient ) {
			delete_transient( 'cyp_json_products' );
		}

		$query = apply_filters( 'cyp_get_products', $query );
		
		return $query;
	}

	/**
	 * Get export products - NOT IN USE 
	 */
	public function cyp_get_export_products() {

		wp_verify_nonce( 'download_id' );
		$data         = wp_unslash( $_POST );
		$download_ids = ( isset( $data['download_ids'] ) ) ? $data['download_ids'] : '';

		$args = array(
			'orderby' => 'title',
			'order'   => 'ASC',
			'limit'   => -1,
		);

		if ( strlen( $download_ids ) > 0 ) {
			$ids             = array_map( 'intval', explode( ',', $download_ids ) );
			$args['include'] = $ids;
		}

		return wc_get_products( array( $args ) );

	}

	/**
	 * Get orders
	 */
	public function cyp_get_product_report() {

		$cyp_options   = get_option( 'cyp_options' );
		$post_per_page = ( $cyp_options['cyp_report_per_page'] > 0 ) ? $cyp_options['cyp_report_per_page'] : 200;
		$date_from     = ( strlen( filter_input( 1, 'date_from', FILTER_DEFAULT ) ) > 0 ) ? filter_input( 1, 'date_from', FILTER_DEFAULT ) : '';
		$date_to       = ( strlen( filter_input( 1, 'date_to', FILTER_DEFAULT ) ) > 0 ) ? filter_input( 1, 'date_to', FILTER_DEFAULT ) : '';
		$page_num      = ( strlen( filter_input( 1, 'paged', FILTER_DEFAULT ) ) > 0 ) ? filter_input( 1, 'paged', FILTER_DEFAULT ) : 1;
		$range         = ( strlen( filter_input( 1, 'range', FILTER_DEFAULT ) ) > 0 ) ? filter_input( 1, 'range', FILTER_DEFAULT ) : '';
		
		if ( strlen( filter_input( 1, 'csv', FILTER_DEFAULT ) ) > 0 ) {
			$post_per_page = ( $cyp_options['cyp_report_csv_max_count'] > 0 ) ? $cyp_options['cyp_report_csv_max_count'] : 5000;
		}

		//Remove some statuses (include specials from i.e Order Status Manager) 
		$order_statuses = array();
		$order_statuses = wc_get_order_statuses();

		unset( $order_statuses['wc-refunded'] );
		unset( $order_statuses['wc-failed'] );
		unset( $order_statuses['wc-cancelled'] );

		$order_statuses = apply_filters( 'cyp_order_statuses', $order_statuses );

		$args = array(
			'orderby' => 'date_created',
			'order'   => 'DESC',
			'type'    => 'shop_order',
			'status'  => array_keys( $order_statuses ),
			'limit'   => -1,
		);

		//Set default range
		if ( strlen( $range ) === 0 && strlen( $date_from ) === 0 && strlen( $date_to ) === 0 ) {
			$range = 'this_month';
		}
		
		if ( strlen( $range ) > 0 ) {

			switch ( $range ) {
				case 'week':
					$date_from = strtotime( '-8 days' );
					$date_to   = strtotime( 'tomorrow' );
					break;
				case 'this_month':
					$date_from = gmdate('Y-m-01');
					$date_to   = strtotime( 'last day of this month' );
					break;
				case 'last_month':
					$date_from = strtotime( 'first day of previous month' );
					$date_to   = strtotime( 'last day of previous month' );
					break;
				case 'year':
					$date_from = strtotime( 'January 01' );
					$date_to   = strtotime( 'tomorrow' );
					break;	
			}

		}

		if ( strlen( $date_from ) > 0 && strlen( $date_to ) > 0 ) {
			$d = array(
				'date_created' => $date_from . '...' . $date_to,
			);

			$args = array_merge( $args, $d );
		}


		if ( $post_per_page > 0 ) {
			
			$p = array(
				'page'     => $page_num,
				'paginate' => true,
				'limit'    => $post_per_page,
			);
			
			$args = array_merge( $args, $p );
		}

		$args = apply_filters( 'cyp_get_product_report', $args );

		return wc_get_orders( $args );
	
	}

	/**
	 * Get JSON products
	 *
	 */
	public function cyp_get_json_products() {

		$query          = $this->cyp_get_products();
		$trans_products = get_transient( 'cyp_json_products' );
	
		if ( $trans_products ) {
			return $trans_products;
		}

		$products = $query->get_products();
		$page_num = ( strlen( filter_input( 1, 'paged', FILTER_DEFAULT ) ) > 0 ) ? filter_input( 1, 'paged', FILTER_DEFAULT ) : 1;
		
		$json_products = array( 
			'rows'      => array(), 
			'total'     => 0,
			'num-pages' => 0,
			'page'      => $page_num,
		);

		if ( $products ) {
			
			foreach ( (array) $products as $key => $value ) {
				
				$p_array = array();

				if ( 'products' === $key ) {
					
					foreach ( (array) $value as $prod_key => $product ) {
						$p_array = $this->cyp_push_products( $product, $p_array );
						$p_array = array_unique( $p_array, SORT_REGULAR );
					}
					
				} elseif ( is_object( $value ) && 'product' === $value->post_type ) {
					$product = $value;
					$p_array = $this->cyp_push_products( $product, $p_array );
					$p_array = array_unique( $p_array, SORT_REGULAR );
				}

				$json_products['rows'][] = $p_array;

			}

			asort( $json_products['rows'] );
			$json_products['total']     = $products->total;
			$json_products['num-pages'] = $products->max_num_pages;
			
			//Set transient
			set_transient( 'cyp_json_products', $json_products, 30 * MINUTE_IN_SECONDS );

			return $json_products;
		}
	}

	/**
	 * Function for push to product array
	 *
	 * @param var $product object.
	 * @param array $p_array array.
	 */
	public function cyp_push_products( $product, $p_array) {
		
		if ( count( $product->get_children() ) > 0 ) {

			$children = $product->get_children();

			foreach ( $children as $value ) {
				$child     = wc_get_product( $value );
				$p_array[] = (object) $child;
			}

		} else {
			$p_array[] = (object) $product;
		}

		return $p_array;

	}

	/**
	 * Loop products
	 */
	public function cyp_loop_products() {

		global $cyp_templates;

		$page_num    = ( strlen( filter_input( 1, 'paged', FILTER_DEFAULT ) ) > 0 ) ? filter_input( 1, 'paged', FILTER_DEFAULT ) : 1;
		$p_obj       = $this->cyp_get_json_products();
		$products    = (array) $p_obj['rows'][0];
		$total_pages = $p_obj['num-pages'];
		$items       = $products;
		$row_count   = $p_obj['total'];

		foreach ( $items as $key => $value ) {
			
			if ( $value instanceof WC_Product && $value->is_type( 'simple' ) || $value instanceof WC_Product_Subscription  ) {
				$cyp_templates->cyp_get_table_row( $value, false, 0 );
			} else {
				if ( $value instanceof WC_Product_Variation || $value instanceof WC_Product_Variable_Subscription ) {
					$cyp_templates->cyp_get_table_row( $value, true, 0 );
				}
			}

		}

		$this->cyp_make_paging_buttons( $total_pages, $page_num, $row_count );

	}

	/**
	 * Create paging buttons
	 */
	public function cyp_make_paging_buttons( $total_pages, $page_num, $total_rows ) {

		$product_cat    = filter_input( 1, 'product_cat', FILTER_DEFAULT );
		$product_search = filter_input( 1, 'product_search', FILTER_DEFAULT );
		$view           = ( strlen( filter_input( 1, 'view', FILTER_DEFAULT ) ) > 0 ) ? filter_input( 1, 'view', FILTER_DEFAULT ) : 'main';
		$range          = ( strlen( filter_input( 1, 'range', FILTER_DEFAULT ) ) > 0 ) ? filter_input( 1, 'range', FILTER_DEFAULT ) : 'this_month';
		$query_strings  = '';

		if ( strlen( $product_cat ) > 0 ) {
			$query_strings .= '&product_cat=' . $product_cat;
		}
		if ( strlen( $product_search ) > 0 ) {
			$query_strings .= '&product_search=' . $product_search;
		}
		
		$current_url = admin_url( 'admin.php?page=crw&view=main&paged=%1$s' . $query_strings );

		if ( 'rep' === $view ) {
			$current_url = admin_url( 'admin.php?page=crw&view=rep&paged=%1$s&range=' . $range );
		}

		$button_html = '<div id="cyp-pages">';

		if ( $total_pages > 1 ) {
			$prev_page  = 1;
			$next_page  = $total_pages;
			$prev_class = '';
			$next_class = '';

			if ( $page_num > 1 ) {
				$prev_page = $page_num - 1;
			} else {
				$prev_class = 'disabled';
			}

			if ( $page_num < $total_pages ) {
				$next_page = $page_num + 1;
			} else {
				$next_class = 'disabled';
			}

			$button_html .= '<a class="cyp-button ' . $prev_class . '" href="' . sprintf( esc_url( $current_url ), 1 ) . '"><i class="fas fa-angle-double-left"></i></a>';
			$button_html .= '<a class="cyp-button ' . $prev_class . '" href="' . sprintf( esc_url( $current_url ), $prev_page ) . '"><i class="fas fa-angle-left"></i></a>';
			
			/* translators: %s: page of pages */
			$page_txt     = __( ' page %1$s of %2$s ', 'woo-calculate-your-price' );
			$button_html .= sprintf( $page_txt, $page_num, $total_pages );
			
			$button_html .= '<a class="cyp-button ' . $next_class . '" href="' . sprintf( esc_url( $current_url ), $next_page ) . '"><i class="fas fa-angle-right"></i></a>';
			$button_html .= '<a class="cyp-button ' . $next_class . '" href="' . sprintf( esc_url( $current_url ), $total_pages ) . '"><i class="fas fa-angle-double-right"></i></a>';
		}
		$button_html .= '</div>';
		?>
		<script>
			var paging_buttons = '<?php echo wp_kses( $button_html, $this->wbs_get_allowed_html() ); ?>';
			
			jQuery( '#cyp-paging-top' ).empty();
			jQuery( '#cyp-paging-top' ).append( paging_buttons );

		</script>
		<?php
		
	}

	/**
	 * Get product name
	 *
	 * @param var $product product.
	 */
	public function cyp_get_product_name( $product ) {
		
		$product_name = ( $product->get_title() ) ? $product->get_title() : '';
		$attributes   = $product->get_attributes();

		if ( strlen( $product_name ) > 0 && isset( $attributes ) && is_array( $attributes ) ) {
			
			foreach ( $attributes as $key => $val ) {
				if ( isset( $val ) && is_string( $val ) && strlen( $val ) > 0 ) {
					$product_name .= ', ' . ucfirst( $val );
				}
			}
			
		}

		return $product_name;
	}

	/**
	 * Get allowed html
	 */
	public function wbs_get_allowed_html() {
		
		$html = array(
			'div'    => array(
				'id'    => array(),
				'class' => array(),
				'style' => array(),
			),
			'span'   => array(
				'id'    => array(),
				'class' => array(),
				'style' => array(),
			),
			'i'   => array(
				'id'    => array(),
				'class' => array(),
				'style' => array(),
			),
			'a'   => array(
				'id'    => array(),
				'class' => array(),
				'style' => array(),
				'href'  => array(),
			)
		);
		return $html;
	}


	/**
	 * Move product to trash
	 *
	 * @param var $post product.
	 */
	public function cyp_move_to_trash( $post ) {
		
		if ( ! isset( $post['id'] ) ) {
			die();
		}

		$id      = sanitize_text_field( $post['id'] );
		$product = wc_get_product( $id );

		$product->set_status( 'trash' );
		$product->save();

	}


	/**
	 * Get product categories - select box
	 *
	 * @param var $prodcat object.
	 */
	public function cyp_get_categories_select( $prodcat ) {

		$args = array(
			'pad_counts'         => 1,
			'show_count'         => 1,
			'hierarchical'       => 1,
			'hide_empty'         => 1,
			'show_uncategorized' => 1,
			'orderby'            => 'name',
			'selected'           => $prodcat,
			'show_option_none'   => __( 'Select Category ( all )', 'woo-calculate-your-price' ),
			'option_none_value'  => '',
			'value_field'        => 'slug',
			'taxonomy'           => 'product_cat',
			'name'               => 'product_cat',
			'class'              => 'dropdown_product_cat',
		);
		?>
		<form name="gc" type="get" action="admin.php" onchange="submit();">   
		<input type="hidden" name="page" value="crw">
		<?php
			wp_dropdown_categories( apply_filters( 'cyp_category_selector_args', $args ) );
			wp_reset_postdata();
		?>
		</form>
		<?php
	}

	/**
	 * Get product categories - select box
	 *
	 * @param var $prodcat object.
	 */
	public function cyp_get_categories_select_no_form( $prodcat ) {

		$args = array(
			'hide_empty'        => 0,
			'taxonomy'          => 'product_cat',
			'hierarchical'      => 1,
			'show_count'        => 1,
			'name'              => 'product_cat',
			'orderby'           => 'product_cat',
			'order'             => 'asc',
			'show_option_none'  => __( 'Select category', 'woo-calculate-your-price' ),
			'option_none_value' => '',
			'selected'          => $prodcat,
		);
		?>
		<?php
			wp_dropdown_categories( apply_filters( 'cyp_category_selector_args', $args ) );
			wp_reset_postdata();
		?>
		<?php
	}

	/**
	 * Check for autofocus
	 *
	 * @param var $field string field.
	 */
	public function cyp_get_autofocus_value( $field = '' ) {
		
		$mouseover_value = 'this.focus();removeNull();';
		$cyp_options     = get_option( 'cyp_options' );

		if ( 'stock' === $field || 'new_price' === $field ) {
			$mouseover_value = 'this.focus();';
		}

		if ( 'yes' === $cyp_options['cyp_no_autofocus'] ) {
			$mouseover_value = '';
		}
		
		return $mouseover_value;
	
	}

	/**
	 * Show shipping cost in table?
	 */
	public function cyp_show_shipping_cost() {
		
		$options = get_option( 'cyp_options' );

		if ( 'yes' === $options['cyp_show_shipping_cost_tbl'] ) {
			return true;
		}
		
		return false;
	
	}

	/**
	 * Get label from settings
	 */
	public function cyp_get_label_name( $label ) {
		
		$options = get_option( 'cyp_options' );

		switch ( $label ) {
			case 'other_cost':
				$option = $options['cyp_other_cost_name'];
				$label  = ( strlen( $option ) > 0 ) ? $option : __( 'Other cost', 'woo-calculate-your-price' );
				break;
			case 'shipping_cost':
				$option = $options['cyp_shipping_cost_name'];
				$label  = ( strlen( $option ) > 0 ) ? $option : __( 'Shipping', 'woo-calculate-your-price' );
				break;
		}
		
		return $label;
	
	}

	/**
	 * Find and show role for order
	 */
	public function cyp_get_order_role( $customer_id ) {
		
		$wp_roles      = wp_roles();
		$customer      = get_userdata( $customer_id );
		$customer_role = ( ! empty( $customer ) ) ? implode( '', $customer->roles ) : '';
		$_roles        = $wp_roles->get_names();

		if ( strlen( $customer_role ) > 0 ) {
			$customer_role = translate_user_role( $_roles[ $customer_role ] );
		}

		return $customer_role;

	}

	/**
	 * Create sales report csv file
	 */
	public function cyp_create_report_csv_export_file() {

		$tab           = ( strlen( filter_input( 1, 'tab', FILTER_DEFAULT ) ) > 0 ) ? filter_input( 1, 'tab', FILTER_DEFAULT ) : 'orders';
		$file_name     = 'cyp-order-report-' . $tab . '-' . gmdate('Y-M-d H:i') . '.csv';
		$results       = $this->cyp_get_product_report();
		$orders        = $results->orders;
		$cyp_options   = get_option( 'cyp_options' );
		$date_format   = get_option( 'date_format' );
		$t_sep         = get_option( 'woocommerce_price_thousand_sep' );
		$d_point       = get_option( 'woocommerce_price_decimal_sep' );
		$decimals      = get_option( 'woocommerce_price_num_decimals' );
		$cog_field     = ( $cyp_options['cyp_cost_of_goods_field'] ) ? $cyp_options['cyp_cost_of_goods_field'] : '_cost_of_goods';
		$p_price_field = ( $cyp_options['cyp_purchase_price_field'] ) ? $cyp_options['cyp_purchase_price_field'] : '_purchase_price';
		
		$head_orders_csv = array(
			__( 'Order ID', 'woo-calculate-your-price' ), 
			__( 'Customer', 'woo-calculate-your-price' ),
			__( 'Role', 'woo-calculate-your-price' ),
			__( 'Date', 'woo-calculate-your-price' ),
			__( 'Status', 'woo-calculate-your-price' ),
			__( 'Items', 'woo-calculate-your-price' ),
			__( 'Profit', 'woo-calculate-your-price' ),
			__( 'Profit %', 'woo-calculate-your-price' ),
			__( 'Cost of goods', 'woo-calculate-your-price' ),
			__( 'Net sales', 'woo-calculate-your-price' ),
			__( 'Tax', 'woo-calculate-your-price' ),
			__( 'Shipping', 'woo-calculate-your-price' ),
		);

		$head_products_csv = array(
			__( 'Order ID', 'woo-calculate-your-price' ), 
			__( 'Category', 'woo-calculate-your-price' ), 
			__( 'Product', 'woo-calculate-your-price' ),
			__( 'SKU', 'woo-calculate-your-price' ),
			__( 'Qty', 'woo-calculate-your-price' ),
			__( 'Price', 'woo-calculate-your-price' ),
			__( 'Net sale', 'woo-calculate-your-price' ),
			__( 'Profit', 'woo-calculate-your-price' ),
			__( 'Profit %', 'woo-calculate-your-price' ),
		);

		global $product;

		$total_puchase = 0;
		$csv           = implode( ';', ( 'orders' === $tab ) ? $head_orders_csv : $head_products_csv );
		$rows          = array();

		foreach ( $orders as $order ) {
			
			$profit        = 0;
			$cost_of_goods = 0;

			foreach ( $order->get_items() as $item ) { 

				$id       = ( $item->get_variation_id() > 0 ) ? $item->get_variation_id() : $item->get_product_id();
				$product  = wc_get_product( $id );
				$cost     = ( strlen( $item->get_meta( $cog_field ) ) > 0 ) ? $item->get_meta( $cog_field ) : get_post_meta( $id, $cog_field, true );
				$purchase = ( strlen( $item->get_meta( $p_price_field ) ) > 0 ) ? $this->cyp_string_to_float( $item->get_meta( $p_price_field ) ) : $this->cyp_string_to_float( get_post_meta( $id, $p_price_field, true ) );
				
				if ( 'orders' === $tab ) {
					$cost_of_goods += ( isset( $cost ) && (float) $cost > 0 ) ? floatval( $cost * $item->get_quantity() ) : 0;
					$total_puchase += ( isset( $purchase ) && (float) $purchase > 0 ) ? floatval( $purchase * $item->get_quantity() ) : 0;
				} else {
					$cost_of_goods = ( isset( $cost ) && (float) $cost > 0 ) ? floatval( $cost * $item->get_quantity() ) : 0;
				}

				$profit     = ( $cost_of_goods > 0 ) ? floatval( $item->get_total() ) - floatval( $cost_of_goods ) : 0;
				$percent    = ( $profit > 0 ) ? floatval( $profit ) * 100 / floatval( $item->get_total() ) : 0;
				$price      = (float) $item->get_total() / (int) $item->get_quantity();
				$terms      = ( $item->get_variation_id() > 0 ) ? get_the_terms( $product->get_parent_id(), 'product_cat' ) : get_the_terms( $id, 'product_cat' );
				$categories = '';

				if ( 'products' === $tab ) {
					
					if ( $terms ) {
						foreach ( $terms as $category ) {
							$categories .= $category->name . ', ';
						}
						$categories = substr( $categories, 0, strlen( $categories ) -2 );
					}
					
					$row = array(
						$order->get_id(),
						$categories,
						$this->cyp_get_product_name( $product ),
						$product->get_sku(),
						$item->get_quantity(),
						number_format( (float) $price, $decimals, $d_point, $t_sep ),
						number_format( (float) $item->get_total(), $decimals, $d_point, $t_sep ),
						number_format( (float) $profit, $decimals, $d_point, $t_sep ),
						number_format( (float) $percent, 2, $d_point, $t_sep ),
					);

					array_push( $rows, $row );

				}
			
			}

			if ( 'orders' === $tab ) {

				$profit  = ( $cost_of_goods > 0 ) ? floatval( $order->get_total() ) - floatval( $cost_of_goods ) : 0;
				$percent = ( $profit > 0 ) ? floatval( $profit ) * 100 / floatval( $order->get_total() ) : 0;
				
				$row = array(
					$order->get_id(),
					$order->get_billing_first_name() . ' ' . $order->get_billing_last_name(),
					$this->cyp_get_order_role( $order->get_customer_id() ),
					date_format( $order->get_date_created(), $date_format ),
					$order->get_status(),
					$order->get_item_count(),
					number_format( (float) $profit, $decimals, $d_point, $t_sep ),
					number_format( (float) $percent, 2, $d_point, $t_sep ),
					number_format( (float) $cost_of_goods, $decimals, $d_point, $t_sep ),
					number_format( (float) $order->get_total(), $decimals, $d_point, $t_sep ),
					number_format( (float) $order->get_total_tax(), $decimals, $d_point, $t_sep ),
					number_format( (float) $order->get_total_shipping(), $decimals, $d_point, $t_sep ),
				);

				array_push( $rows, $row );

			}

		}

		$csv .= "\n";
		foreach ( $rows as $item ) {
			$csv .= implode( ';', $item );
			$csv .= "\n";
		}
	  
		header( 'Content-Type: text/csv' ); 
		header( 'Content-Disposition: attachment; filename="' . $file_name . '"' );
		header( 'Pragma: no-cache' ); 
		header( 'Expires: Sat, 26 Jul 2010 05:00:00 GMT' );
	
		echo esc_attr( $csv );

		exit;

	}

	/**
	 * Create csv file
	 *
	 */
	public function cyp_create_csv_export_file() {

		$file_name      = 'cyp-products-' . gmdate('Y-M-d H:i') . '.csv';
		$query          = $this->cyp_get_products();
		$all_products   = $this->cyp_get_json_products( $query );
		$products       = (array) $all_products['rows'][0];
		$cyp_options    = get_option( 'cyp_options' );
		$cog_field      = ( $cyp_options['cyp_cost_of_goods_field'] ) ? $cyp_options['cyp_cost_of_goods_field'] : '_cost_of_goods';
		$p_price_field  = ( $cyp_options['cyp_purchase_price_field'] ) ? $cyp_options['cyp_purchase_price_field'] : '_purchase_price';
		$other_cost_lbl = $this->cyp_get_label_name( 'other_cost' );

		$head_csv = array(
			__( 'ID', 'woo-calculate-your-price' ), 
			__( 'Name', 'woo-calculate-your-price' ), 
			__( 'SKU', 'woo-calculate-your-price' ),
			__( 'Purchase price', 'woo-calculate-your-price' ),
			$other_cost_lbl,
			__( 'Cost of goods', 'woo-calculate-your-price' ),
			__( 'Markup', 'woo-calculate-your-price' ),
			__( 'Price', 'woo-calculate-your-price' ),
			__( 'Stock', 'woo-calculate-your-price' ),
			__( 'Value at cost', 'woo-calculate-your-price' ),
			__( 'Retail value', 'woo-calculate-your-price' ),
			__( 'Profit', 'woo-calculate-your-price' ),
			__( 'Modified', 'woo-calculate-your-price' ),
		);

		$shipping_cost_exists = false;

		if ( $this->cyp_show_shipping_cost() ) {
			array_splice( $head_csv, 5, 0, $this->cyp_get_label_name( 'shipping_cost' ) );
			$shipping_cost_exists = true;
		}

		$csv      = implode( ';', $head_csv );
		$rows     = array();
		$t_sep    = get_option( 'woocommerce_price_thousand_sep' );
		$d_point  = get_option( 'woocommerce_price_decimal_sep' );
		$decimals = get_option( 'woocommerce_price_num_decimals' );

		foreach ( $products as $key => $p ) {
				
			$product_name   = preg_replace('/[^A-Za-z0-9. -]/', '', $p->get_title() );
			$cost_of_goods  = $this->cyp_string_to_float( get_post_meta( $p->get_id(), $cog_field, true ) );
			$stock          = $p->get_stock_quantity();
			$price          = $p->get_regular_price();
			$purchase_price = $this->cyp_string_to_float( get_post_meta( $p->get_id(), $p_price_field, true ) );
			$other_cost     = $this->cyp_string_to_float( get_post_meta( $p->get_id(), '_other_cost', true ) );
			$shipping_cost  = '';
			$val_cost       = (float) $cost_of_goods * (float) $stock;
			$val_sale       = (float) $price * (float) $stock;
			$profit         = (float) $val_sale - (float) $val_cost;

			if ( $shipping_cost_exists ) {
				$shipping_cost = $this->cyp_string_to_float( get_post_meta( $p->get_id(), '_cyp_shipping_cost', true ) );
			}
			
			$attributes = $p->get_attributes();

			if ( isset( $attributes ) && is_array( $attributes ) ) {
				foreach ( $attributes as $key => $val ) {
					if ( isset( $val ) && is_string( $val ) && strlen( $val ) > 0 ) {
						$product_name .= ', ' . $val;
					}
				}
			}

			$row = array(
				$p->get_id(),
				$product_name,
				$p->get_sku(),
				number_format( (float) $purchase_price, $decimals, $d_point, $t_sep ),
				number_format( (float) $other_cost, $decimals, $d_point, $t_sep ),
				number_format( (float) $cost_of_goods, $decimals, $d_point, $t_sep ),
				number_format( (float) get_post_meta( $p->get_id(), '_markup_percent', true ), $decimals, $d_point, $t_sep ),
				number_format( (float) $price, $decimals, $d_point, $t_sep ),
				$stock,
				number_format( (float) $val_cost, $decimals, $d_point, $t_sep ),
				number_format( (float) $val_sale, $decimals, $d_point, $t_sep ),
				number_format( $profit, $decimals, $d_point, $t_sep ),
				$p->get_date_modified()->format('y-m-d'),
			);
			if ( $shipping_cost_exists ) {
				array_splice( $row, 5, 0, $shipping_cost );
			}
			array_push( $rows, $row );
		};

		$csv .= "\n";
		foreach ( $rows as $item ) {
			$csv .= implode( ';', $item );
			$csv .= "\n";
		}

		header( 'Content-Type: text/csv' ); 
		header( 'Content-Disposition: attachment; filename="' . $file_name . '"' );
		header( 'Pragma: no-cache' ); 
		header( 'Expires: Sat, 26 Jul 2010 05:00:00 GMT' );
	
		echo esc_attr( $csv );

		exit;

	}

	/**
	 * Convert string to float
	 */
	public function cyp_string_to_float( $val ) {

		$val = str_replace( ',', '.', $val );
		$val = preg_replace( '/\.(?=.*\.)/', '', $val );
		return floatval( $val );

	}
}


