<?php
/**
 * Cost & Reports - reports
 *
 * @package CostReports/includes
 */

defined( 'ABSPATH' ) || exit;

require_once __DIR__ . '/class-cyp-functions.php';

/**
 * Class for reports
 */
class Cyp_Report {
	
	/**
	 * CypFunctions
	 *
	 * @var var $functions.
	 */
	public $functions;

	/**
	 * CypOptions
	 *
	 * @var var $cyp_options.
	 */
	public $cyp_options;

	/**
	 * Constructor
	 */
	public function __construct() {
		$this->functions   = new Cyp_Functions();
		$this->cyp_options = get_option( 'cyp_options' );
	}

	/**
	 * Get main page
	 */
	public function cyp_get_main_page() {

		$tab = ( strlen( filter_input( 1, 'tab', FILTER_DEFAULT ) ) > 0 ) ? filter_input( 1, 'tab', FILTER_DEFAULT ) : 'orders';
		
		?>
		<div class="cyp-main">
		<?php
		$this->cyp_get_top_header();

		switch ( $tab ) {
			case 'orders':
				$this->cyp_get_table();
				break;
			case 'products':
				$this->cyp_get_table_products();
				break;
			case 'customers':
				$this->cyp_rep_get_customer_table();
				break;
			default:
				$this->cyp_get_table();
				break;
		}

		?>
		</div>
		<?php
	}

	/**
	 * Get header and search
	 */
	public function cyp_get_top_header() {

		$range   = ( strlen( filter_input( 1, 'range', FILTER_DEFAULT ) ) > 0 ) ? filter_input( 1, 'range', FILTER_DEFAULT ) : 'this_month';
		$tab     = ( strlen( filter_input( 1, 'tab', FILTER_DEFAULT ) ) > 0 ) ? filter_input( 1, 'tab', FILTER_DEFAULT ) : 'orders';
		$date_f  = ( strlen( filter_input( 1, 'date_from', FILTER_DEFAULT ) ) > 0 ) ? filter_input( 1, 'date_from', FILTER_DEFAULT ) : '';
		$date_t  = ( strlen( filter_input( 1, 'date_to', FILTER_DEFAULT ) ) > 0 ) ? filter_input( 1, 'date_to', FILTER_DEFAULT ) : '';
		$url     = admin_url( 'admin.php?page=crw&view=rep' );
		$refresh = $this->cyp_options['cyp_report_order_refresh'];

		$date_range = '&range=' . $range;

		if ( strlen( $date_f ) > 0 ) {
			$date_range = '&date_from=' . $date_f . '&date_to=' . $date_t;
		}

		?>
		<div class="wrap">
			<h1 class="wp-heading-inline"><?php esc_html_e( 'Cost & Reports', 'woo-calculate-your-price' ); ?></h1>
		</div>
		<div class="wrap woocommerce">
			<nav class="nav-tab-wrapper woo-nav-tab-wrapper">
				<a href="<?php echo esc_url( $url . '&tab=orders' . $date_range ); ?>" class="nav-tab <?php echo ( 'orders' === $tab ) ? 'nav-tab-active' : ''; ?>"><?php esc_attr_e( 'Orders', 'woo-calculate-your-price' ); ?></a>
				<a href="<?php echo esc_url( $url . '&tab=products' . $date_range ); ?>" class="nav-tab <?php echo ( 'products' === $tab ) ? 'nav-tab-active' : ''; ?>"><?php esc_attr_e( 'Products', 'woo-calculate-your-price' ); ?></a>
				<a href="<?php echo esc_url( $url . '&tab=customers' . $date_range ); ?>" class="nav-tab <?php echo ( 'customers' === $tab ) ? 'nav-tab-active' : ''; ?>"><?php esc_attr_e( 'Customers', 'woo-calculate-your-price' ); ?></a>
			</nav>
			<div class="cyp-in-flexll" style="margin-top:15px;margin-bottom:15px;">
				<?php $this->functions->cyp_get_view_buttons(); ?>
				<span>
					<?php
					$order_count = wc_processing_order_count();
					?>
					<?php wp_nonce_field( 'footer_id' ); ?>
					<input type="hidden" id="cyp-auto-orders-value" value="<?php echo esc_attr( number_format_i18n( $order_count ) ); ?>">
					<?php esc_html_e( 'New orders:', 'woo-calculate-your-price' ); ?> <span class="cyp_circle" id="cyp-auto-orders-value-out"><?php echo esc_attr( number_format_i18n( $order_count ) ); ?></span>
					<span style="margin-left: 10px;color:gray;"><input type="checkbox" id="cyp-auto-orders" <?php echo esc_attr( 'yes' === $refresh ) ? 'checked="checked"' : ''; ?> disabled> <?php esc_html_e( 'Refresh on new orders', 'woo-calculate-your-price' ); ?></span>
				</span>
				<div style="float:right;">
					<input type="search" class="input-txt-search" oninput="reportFilter('<?php echo esc_js( $tab ); ?>');" onmouseover="<?php echo esc_js( $this->functions->cyp_get_autofocus_value( '' ) ); ?>" placeholder="<?php esc_html_e( 'search in rows', 'woo-calculate-your-price' ); ?>" id="report_search" name="report_search">
				</div>
			</div>
			<ul class="subsubsub" style="margin-bottom:10px;">
				<li><a href="<?php echo esc_url( $url . '&range=year&tab=' . $tab ); ?>" <?php echo ( 'year' === $range ) ? 'class="cyp-active"' : ''; ?>><?php esc_attr_e( 'Year', 'woo-calculate-your-price' ); ?></a> | </li>
				<li><a href="<?php echo esc_url( $url . '&range=last_month&tab=' . $tab ); ?>" <?php echo ( 'last_month' === $range ) ? 'class="cyp-active"' : ''; ?>><?php esc_attr_e( 'Last month', 'woo-calculate-your-price' ); ?></a> | </li>
				<li><a href="<?php echo esc_url( $url . '&range=this_month&tab=' . $tab ); ?>" <?php echo ( 'this_month' === $range ) ? 'class="cyp-active"' : ''; ?>><?php esc_attr_e( 'This month', 'woo-calculate-your-price' ); ?></a> | </li>
				<li><a href="<?php echo esc_url( $url . '&range=week&tab=' . $tab ); ?>" <?php echo ( 'week' === $range ) ? 'class="cyp-active"' : ''; ?>><?php esc_attr_e( 'Last 7 days', 'woo-calculate-your-price' ); ?></a> |</li>
				<li><?php esc_attr_e( 'Custom:', 'woo-calculate-your-price' ); ?>
				<form method="GET" action="admin.php" class="cyp-in-flex" autocomplete="off">
					<input type="hidden" name="page" value="crw">
					<input type="hidden" name="view" value="rep">
					<input type="hidden" name="tab" value="<?php esc_attr_e( $tab ); ?>">
					<input type="text" class="input-date" name="date_from" id="date_from" placeholder="<?php ( $date_f ) ? esc_attr_e( $date_f ) : esc_attr_e( 'Date from', 'woo-calculate-your-price' ); ?>" onfocus="this.value='';">
					<input type="text" class="input-date" name="date_to" id="date_to" placeholder="<?php ( $date_t ) ? esc_attr_e( $date_t ) : esc_attr_e( 'Date to', 'woo-calculate-your-price' ); ?>" onfocus="this.value='';">
					<button type="submit" id="btn-go" class="button" style="margin-left: 5px;"><?php esc_attr_e( 'Go', 'woo-calculate-your-price' ); ?></button>
				</form>
				</li>
				<li>
				<?php if ( 'customers' !== $tab ) : ?>
					<form method="post" id="download_report" action="<?php esc_attr_e( admin_url( 'admin-post.php?csv=true&tab=' . $tab . $date_range ) ); ?>">
						<input type="hidden" name="action" value="return_report_csv_file">
						<button type="submit" name="download_report" class="button" style="margin-top:-3px;margin-left:2px;">
						<i class="fas fa-cloud-download-alt"></i> <?php esc_attr_e( 'Download (.csv)', 'woo-calculate-your-price' ); ?>
						</button>
					</form>
				<?php endif; ?>
				</li>
				<li>
					<button class="button" onclick="cyp_export_html_table('<?php echo esc_js( $tab ); ?>');" style="margin-top:-3px;margin-left:2px;"><i class="fas fa-file-export"></i> <?php esc_attr_e( 'Export table', 'woo-calculate-your-price' ); ?></button>
				</li>
				
			</ul>
			<div id="cyp-paging-top" class="div-paging">
			
			</div>
		</div>
		<?php
	}

	/**
	 * Get Orders table report
	 */
	public function cyp_get_table() {
		
		$results       = $this->functions->cyp_get_product_report();
		$orders        = $results->orders;
		$cyp_options   = get_option( 'cyp_options' );
		$profit_good   = $cyp_options['cyp_good_profit_percent'];
		$profit_bad    = $cyp_options['cyp_bad_profit_percent'];
		$date_format   = get_option( 'date_format' );
		$t_sep         = get_option( 'woocommerce_price_thousand_sep' );
		$d_point       = get_option( 'woocommerce_price_decimal_sep' );
		$decimals      = get_option( 'woocommerce_price_num_decimals' );
		$cog_field     = ( $cyp_options['cyp_cost_of_goods_field'] ) ? $cyp_options['cyp_cost_of_goods_field'] : '_cost_of_goods';
		$p_price_field = ( $cyp_options['cyp_purchase_price_field'] ) ? $cyp_options['cyp_purchase_price_field'] : '_purchase_price';
		$page_num      = ( strlen( filter_input( 1, 'paged', FILTER_DEFAULT ) ) > 0 ) ? filter_input( 1, 'paged', FILTER_DEFAULT ) : 1;
		
		//Create paging
		if ( $results->max_num_pages > 1 ) {
			$this->functions->cyp_make_paging_buttons( $results->max_num_pages, $page_num, $results->total );
		}
		?>
		<div class="cyp-r-row">
		
		<div class="cyp-r-column cyp-r-left" id="div-table-report">
		<table id="table-report" class="wp-list-table widefat fixed striped posts">
			<?php $this->cyp_rep_get_table_header(); ?>
			<tbody>
		<?php
 
		global $product;

		$total_gross   = 0;
		$total_profit  = 0;
		$total_percent = 0;
		$total_puchase = 0;
		$total_items   = 0;
		$total_pp      = 0;
		$total_cog     = 0;
		$total_taxes   = 0;
		$tot_shipping  = 0;

		foreach ( $orders as $order ) {

			$profit        = 0;
			$cost_of_goods = 0;
			$items_total   = 0;

			//Do not include trash orders
			if ( 'trash' === $order->get_status() ) {
				continue;
			}

			foreach ( $order->get_items() as $item ) { 
				
				$id             = ( $item->get_variation_id() > 0 ) ? $item->get_variation_id() : $item->get_product_id();
				$product        = wc_get_product( $id );
				$cost           = ( strlen( $item->get_meta( $cog_field ) ) > 0 ) ? $item->get_meta( $cog_field ) : get_post_meta( $id, $cog_field, true );
				$purchase       = ( strlen( $item->get_meta( $p_price_field ) ) > 0 ) ? $item->get_meta( $p_price_field ) : get_post_meta( $id, $p_price_field, true );
				$cost_of_goods += ( isset( $cost ) && (float) $cost > 0 ) ? floatval( $cost * $item->get_quantity() ) : 0;
				$total_puchase += ( isset( $purchase ) && (float) $purchase > 0 && null !== $item->get_quantity() ) ? floatval( $purchase * $item->get_quantity() ) : 0;
				$items_total   += floatval( $item->get_total() );
				
			}

			$total_items   += $order->get_item_count();
			$total_gross   += $items_total;
			$profit         = ( $cost_of_goods > 0 ) ? floatval( $items_total ) - floatval( $cost_of_goods ) : 0;
			$percent        = ( $profit > 0 ) ? floatval( $profit ) * 100 / floatval( $items_total ) : 0;
			$total_profit  += $profit;
			$total_percent += $percent;
			$total_pp       = ( $total_profit > 0 ) ? floatval( $total_profit ) * 100 / floatval( $total_gross ) : 0;
			$total_cog     += $cost_of_goods;
			$customer_name  = ( null !== $order->get_billing_first_name() && null !== $order->get_billing_last_name() ) ? $order->get_billing_first_name() . ' ' . $order->get_billing_last_name() : '';
			$total_taxes   += $order->get_total_tax();
			$tot_shipping  += $order->get_shipping_total();

			?>
			<tr class="lozad" data-exclude="">
				<td><a href="post.php?post=<?php echo esc_attr( $order->get_id() ); ?>&action=edit"><?php echo esc_attr( $order->get_id() ); ?></a></td>
				<td><a href="user-edit.php?user_id=<?php echo esc_attr( $order->get_customer_id() ); ?>"><?php echo esc_attr( $customer_name ); ?></a></td>
				<td><?php esc_attr_e( $this->functions->cyp_get_order_role( $order->get_customer_id() ) ); ?></td>
				<td data-t="d"><?php echo esc_attr( date_format( new DateTime( $order->get_date_created() ), $date_format ) ); ?></td>
				<td style="text-transform:capitalize;"><?php echo esc_attr( $order->get_status() ); ?></td>
				<td class="cyp-center"><?php echo esc_attr( $order->get_item_count() ); ?></td>
				<td class="cyp-right"><?php echo esc_attr( number_format( (float) $profit, $decimals, $d_point, $t_sep ) ); ?></td>
				<td class="cyp-right  <?php echo ( (float) $percent >= $profit_good ) ? 'cyp-good-profit' : ''; ?><?php echo ( (float) $percent <= $profit_bad ) ? 'cyp-bad-profit' : ''; ?>"><?php echo esc_attr( number_format( (float) $percent, 2, $d_point, $t_sep ) ); ?></td>
				<td class="cyp-right"><?php echo esc_attr( number_format( (float) $cost_of_goods, $decimals, $d_point, $t_sep ) ); ?></td>
				<td class="cyp-right"><?php echo esc_attr( number_format( (float) $items_total, $decimals, $d_point, $t_sep ) ); ?></td>
				<td class="cyp-right"><?php echo esc_attr( number_format( (float) $order->get_total_tax(), $decimals, $d_point, $t_sep ) ); ?></td>
				<td class="cyp-right"><?php echo esc_attr( number_format( (float) $order->get_shipping_total(), $decimals, $d_point, $t_sep ) ); ?></td>
			</tr>
			<?php
		}

		?>
			<tfoot>
				<tr>
					<td></td>
					<td></td>
					<td></td>
					<td></td>
					<td></td>
					<td class="cyp-center" id="rep-ord-items"><?php echo esc_attr( number_format( (int) $total_items, 0, $d_point, $t_sep ) ); ?></td>
					<td class="cyp-right" id="rep-ord-profit"><?php echo esc_attr( wp_strip_all_tags( wc_price( $total_profit ) ) ); ?></td>
					<td></td>
					<td class="cyp-right" id="rep-ord-cogs"><?php echo esc_attr( wp_strip_all_tags( wc_price( $total_cog ) ) ); ?></td>
					<td class="cyp-right" id="rep-ord-net"><?php echo esc_attr( wp_strip_all_tags( wc_price( $total_gross ) ) ); ?></td>
					<td class="cyp-right" id="rep-ord-tax"><?php echo esc_attr( wp_strip_all_tags( wc_price( $total_taxes ) ) ); ?></td>
					<td class="cyp-right" id="rep-ord-ship"><?php echo esc_attr( wp_strip_all_tags( wc_price( $tot_shipping ) ) ); ?></td>
				</tr>
			</tfoot>
			</tbody>
		</table>
		</div>
			<div class="cyp-r-column cyp-r-right">
				<div class="cyp-total-group">
				<div class="cyp-total-item" style="border-right: 5px solid #b1d4ea;">
					<h2>
						<?php echo esc_attr( wp_strip_all_tags( wc_price( $total_gross ) ) ); ?>
					</h2>	
					<span><?php esc_html_e( 'net sales in this period', 'woo-calculate-your-price' ); ?></span>
				</div>
				<div class="cyp-total-item" style="border-right: 5px solid #b1d4ea;">
					<h2>
						<?php echo esc_attr( wp_strip_all_tags( wc_price( $total_profit ) ) ); ?>
					</h2>	
					<span><?php esc_html_e( 'profit in this period', 'woo-calculate-your-price' ); ?></span>
				</div>
				<div class="cyp-total-item" style="border-right: 5px solid #3498db;">
					<h2>
						<?php echo esc_attr( number_format( (float) $total_pp, $decimals, $d_point, $t_sep ) . '%' ); ?>
					</h2>	
					<span><?php esc_html_e( 'profit this period', 'woo-calculate-your-price' ); ?></span>
				</div>
				<div class="cyp-total-item" style="border-right: 5px solid #3498db;">
					<h2>
						<?php echo esc_attr( wp_strip_all_tags( wc_price( $total_taxes ) ) ); ?>
					</h2>	
					<span><?php esc_html_e( 'taxes this period', 'woo-calculate-your-price' ); ?></span>
				</div>
				<div class="cyp-total-item" style="border-right: 5px solid khaki;">
					<h2>
						<?php echo esc_attr( wp_strip_all_tags( wc_price( $tot_shipping ) ) ); ?>
					</h2>	
					<span><?php esc_html_e( 'shipping this period', 'woo-calculate-your-price' ); ?></span>
				</div>
				<div class="cyp-total-item" style="border-right: 5px solid #3498db;">
					<h2>
						<?php echo ( (float) $total_percent > 0 && $results->total > 0 ) ? esc_attr( number_format( (float) $total_percent / $results->total, $decimals, $d_point, $t_sep ) . '%' ) : '0%'; ?>
					</h2>	
					<span><?php esc_html_e( 'average profit per order', 'woo-calculate-your-price' ); ?></span>
				</div>
				<div class="cyp-total-item" style="border-right: 5px solid lightsalmon;">
					<h2>
						<?php echo ( (float) $total_profit > 0 && $results->total > 0 ) ? esc_attr( wp_strip_all_tags( wc_price( $total_profit / $results->total ) ) ) : '0'; ?>
					</h2>	
					<span><?php esc_html_e( 'average profit per order', 'woo-calculate-your-price' ); ?></span>
				</div>
				<div class="cyp-total-item" style="border-right: 5px solid darkseagreen;">
					<h2>
						<?php echo esc_attr( wp_strip_all_tags( wc_price( $total_cog ) ) ); ?>
					</h2>	
					<span><?php esc_html_e( 'cost of goods for orders', 'woo-calculate-your-price' ); ?></span>
				</div>
				<div class="cyp-total-item" style="border-right: 5px solid orangered;">
					<h2>
						<?php echo esc_attr( wp_strip_all_tags( wc_price( $total_puchase ) ) ); ?>
					</h2>	
					<span><?php esc_html_e( 'purchase cost for orders', 'woo-calculate-your-price' ); ?></span>
				</div>
				<div class="cyp-total-item" style="border-right: 5px solid #dbe1e3;">
					<h2>
						<?php echo esc_attr( number_format( (int) $results->total, 0, $d_point, $t_sep ) ); ?>
					</h2>	
					<span><?php esc_html_e( 'orders placed', 'woo-calculate-your-price' ); ?></span>
				</div>
				<div class="cyp-total-item" style="border-right: 5px solid #dbe1e3;">
					<h2>
						<?php echo esc_attr( number_format( (int) $total_items, 0, $d_point, $t_sep ) ); ?>
					</h2>	
					<span><?php esc_html_e( 'items purchased', 'woo-calculate-your-price' ); ?></span>
				</div>
				</div>
					
			</div>
		</div>
		
		<?php

	}

	/**
	 * Get table report - products tab
	 */
	public function cyp_get_table_products() {
		
		$results     = $this->functions->cyp_get_product_report();
		$orders      = $results->orders;
		$cyp_options = get_option( 'cyp_options' );
		$profit_good = $cyp_options['cyp_good_profit_percent'];
		$profit_bad  = $cyp_options['cyp_bad_profit_percent'];
		$t_sep       = get_option( 'woocommerce_price_thousand_sep' );
		$d_point     = get_option( 'woocommerce_price_decimal_sep' );
		$decimals    = get_option( 'woocommerce_price_num_decimals' );
		$cog_field   = ( $cyp_options['cyp_cost_of_goods_field'] ) ? $cyp_options['cyp_cost_of_goods_field'] : '_cost_of_goods';
		$page_num    = ( strlen( filter_input( 1, 'paged', FILTER_DEFAULT ) ) > 0 ) ? filter_input( 1, 'paged', FILTER_DEFAULT ) : 1;
		
		//Create paging
		if ( $results->max_num_pages > 1 ) {
			$this->functions->cyp_make_paging_buttons( $results->max_num_pages, $page_num, $results->total );
		}
		?>
		<div class="cyp-r-row">
		
		<div class="cyp-r-column cyp-r-left">
		<table id="table-report" class="wp-list-table widefat fixed striped posts">
		<?php $this->cyp_rep_get_table_header_products(); ?>
		<tbody>
		<?php

		global $product;

		foreach ( $orders as $order ) {
			
			$profit        = 0;
			$cost_of_goods = 0;

			//Do not include trash orders
			if ( 'trash' === $order->get_status() ) {
				continue;
			}

			foreach ( $order->get_items() as $item ) {

				$id            = ( $item->get_variation_id() > 0 ) ? $item->get_variation_id() : $item->get_product_id();
				$product       = wc_get_product( $id );
				$cost          = ( strlen( $item->get_meta( $cog_field ) ) > 0 ) ? $item->get_meta( $cog_field ) : get_post_meta( $id, $cog_field, true );
				$cost_of_goods = ( isset( $cost ) && floatval( $cost ) > 0 ) ? floatval( $cost * $item->get_quantity() ) : 0;
				$profit        = ( $cost_of_goods > 0 ) ? floatval( $item->get_total() ) - floatval( $cost_of_goods ) : 0;
				$percent       = ( $profit > 0 ) ? floatval( $profit ) * 100 / floatval( $item->get_total() ) : 0;
				$price         = (float) $item->get_total() / (int) $item->get_quantity();
				$terms         = ( $item->get_variation_id() > 0 ) ? get_the_terms( $product->get_parent_id(), 'product_cat' ) : get_the_terms( $id, 'product_cat' );
				$categories    = '';
				$url           = admin_url( 'admin.php?page=crw&view=main&product_cat=%1$s' );
			
				if ( $terms ) {
					foreach ( $terms as $category ) {
						$categories .= '<a href="' . sprintf( esc_url( $url ), $category->slug ) . '">' . $category->name . '</a>, ';
					}
					$categories = substr( $categories, 0, strlen( $categories ) -2 );
				}
				?>
				<tr class="lozad" data-exclude="">
					<td><a href="post.php?post=<?php echo esc_attr( $order->get_id() ); ?>&action=edit"><?php echo esc_attr( $order->get_id() ); ?></a></td>
					<td><?php echo wp_kses( $categories, 'post' ); ?></td>
					<td><?php echo esc_attr( $this->functions->cyp_get_product_name( $product ) ); ?></td>
					<td style="font-size: .65rem;text-transform:uppercase;"><?php echo esc_attr( $product->get_sku() ); ?></td>
					<td class="cyp-center"><?php echo esc_attr( (int) $item->get_quantity() ); ?></td>
					<td class="cyp-right"><?php echo esc_attr( number_format( (float) $price, $decimals, $d_point, $t_sep ) ); ?></td>
					<td class="cyp-right"><?php echo esc_attr( number_format( (float) $item->get_total(), $decimals, $d_point, $t_sep ) ); ?></td>
					<td class="cyp-right"><?php echo esc_attr( number_format( (float) $profit, $decimals, $d_point, $t_sep ) ); ?></td>
					<td class="cyp-right <?php echo ( (float) $percent >= $profit_good ) ? 'cyp-good-profit' : ''; ?><?php echo ( (float) $percent <= $profit_bad ) ? 'cyp-bad-profit' : ''; ?>"><?php echo esc_attr( number_format( (float) $percent, 2, $d_point, $t_sep ) ); ?></td>	
				</tr>
				<?php
			}
		}
		?>
		</tbody>
			<?php $this->cyp_rep_get_table_footer_products(); ?>
		</table>
		</div>
		<?php
		//Get report stats
		$this->cyp_rep_get_product_report_right( $results );
	}

	/**
	 * Get table header - products
	 */
	public function cyp_rep_get_table_header_products() {
		?>
		<thead>
			<tr class="head-avr-back">
				<th class="head-avr" style="width:80px;"><?php esc_html_e( 'Average', 'woo-calculate-your-price' ); ?></th>
				<th class="head-avr"></th>
				<th class="head-avr"></th>
				<th class="head-avr"></th>
				<th class="head-avr cyp-center" style="width:60px;" id="avr_qty"></th>
				<th class="head-avr cyp-right" style="width:8%;" id="avr_price"></th>
				<th class="head-avr cyp-right" style="width:10%;" id="avr_sale"></th>
				<th class="head-avr cyp-right" style="width:8%;" id="avr_profit"></th>
				<th class="head-avr cyp-right" style="width:8%;" id="avr_percent"></th>
			</tr>
			<tr>
				<th><a href="#" onclick="sort(0,'number','r','table-report');"><?php esc_html_e( 'Order id', 'woo-calculate-your-price' ); ?></a> <i id="r0" class="fas fa-sort"></i></th>
				<th><a href="#" onclick="sort(1,'text','r','table-report');"><?php esc_html_e( 'Category', 'woo-calculate-your-price' ); ?></a> <i id="r1" class="fas fa-sort"></i></th>
				<th><a href="#" onclick="sort(2,'text','r','table-report');"><?php esc_html_e( 'Product', 'woo-calculate-your-price' ); ?></a> <i id="r2" class="fas fa-sort"></i></th>
				<th><a href="#" onclick="sort(3,'text','r','table-report');"><?php esc_html_e( 'SKU', 'woo-calculate-your-price' ); ?></a> <i id="r3" class="fas fa-sort"></i></th>
				<th class="cyp-center"><a href="#" onclick="sort(4,'number','r','table-report');"><?php esc_html_e( 'Qty', 'woo-calculate-your-price' ); ?></a> <i id="r4" class="fas fa-sort"></i></th>
				<th class="cyp-right"><a href="#" onclick="sort(5,'number','r','table-report');"><?php esc_html_e( 'Price', 'woo-calculate-your-price' ); ?></a> <i id="r5" class="fas fa-sort"></i></th>
				<th class="cyp-right"><a href="#" onclick="sort(6,'number','r','table-report');"><?php esc_html_e( 'Net sale', 'woo-calculate-your-price' ); ?></a> <i id="r6" class="fas fa-sort"></i></th>
				<th class="cyp-right"><a href="#" onclick="sort(7,'number','r','table-report');"><?php esc_html_e( 'Profit', 'woo-calculate-your-price' ); ?></a> <i id="r7" class="fas fa-sort"></i></th>
				<th class="cyp-right"><a href="#" onclick="sort(8,'number','r','table-report');"><?php esc_html_e( 'Profit %', 'woo-calculate-your-price' ); ?></a> <i id="r8" class="fas fa-sort"></i></th>
			</tr>
		</thead>
		<?php
	}

	/**
	 * Get table footer - products
	 */
	public function cyp_rep_get_table_footer_products() {
		?>
		<tfoot>
			<tr>
				<td></td>
				<td></td>
				<td></td>
				<td></td>
				<td id="pr5" class="cyp-center"></td>
				<td id="pr6" class="cyp-right"></td>
				<td id="pr7" class="cyp-right"></td>
				<td id="pr8" class="cyp-right"></td>
				<td id="pr9" class="cyp-right"></td>
			</tr>
		</tfoot>
		<?php
	}

	/**
	 * Get product report right
	 */
	public function cyp_rep_get_product_report_right( $orders ) {
		$t_sep    = get_option( 'woocommerce_price_thousand_sep' );
		$d_point  = get_option( 'woocommerce_price_decimal_sep' );
		$decimals = get_option( 'woocommerce_price_num_decimals' );
		?>
		<div class="cyp-r-column cyp-r-right">
			<div class="cyp-total-group">
				<div class="cyp-total-item" style="border-right: 5px solid goldenrod;">
					<h4><?php esc_html_e( '#1 PRODUCT ', 'woo-calculate-your-price' ); ?> 
						 <?php esc_html_e( 'by quantity: ', 'woo-calculate-your-price' ); ?><b id="pr_top1_item_qty"></b></h4>
					<h2 id="pr_top_product"></h2>	
					<span id="pr_top_product_sku"></span><br/>
					<span><?php esc_html_e( 'profit: ', 'woo-calculate-your-price' ); ?><b id="pr_top1_item_profit"></b></span>
					<span><?php esc_html_e( 'sales: ', 'woo-calculate-your-price' ); ?><b id="pr_top1_sales"></b></span><br/>
					<span><?php esc_html_e( 'total turnover (sales): ', 'woo-calculate-your-price' ); ?><b id="pr_top1_turnover"></b></span><br/>
					<span><?php esc_html_e( 'total turnover (qty): ', 'woo-calculate-your-price' ); ?><b id="pr_top1_turnover_qty"></b></span><br/>
					<span><?php esc_html_e( 'category: ', 'woo-calculate-your-price' ); ?><b id="pr_top1_cat"></b></span>
				</div>
				<div class="cyp-total-item" style="border-right: 5px solid #B4B4B4;">
					<h4><?php esc_html_e( '#2 PRODUCT ', 'woo-calculate-your-price' ); ?> 
						  <?php esc_html_e( 'by quantity: ', 'woo-calculate-your-price' ); ?><b id="pr_top2_item_qty"></b></h4>
					<h2 id="pr_top2_product"></h2>	
					<span id="pr_top2_product_sku"></span><br/>
					<span><?php esc_html_e( 'profit: ', 'woo-calculate-your-price' ); ?><b id="pr_top2_item_profit"></b></span>
					<span><?php esc_html_e( 'sales: ', 'woo-calculate-your-price' ); ?><b id="pr_top2_sales"></b></span><br/>
					<span><?php esc_html_e( 'total turnover (sales): ', 'woo-calculate-your-price' ); ?><b id="pr_top2_turnover"></b></span><br/>
					<span><?php esc_html_e( 'total turnover (qty): ', 'woo-calculate-your-price' ); ?><b id="pr_top2_turnover_qty"></b></span><br/>
					<span><?php esc_html_e( 'category: ', 'woo-calculate-your-price' ); ?><b id="pr_top2_cat"></b></span>		
				</div>
				<div class="cyp-total-item" style="border-right: 5px solid goldenrod;">
					<h4><?php esc_html_e( '#1 PRODUCT ', 'woo-calculate-your-price' ); ?> 
						  <?php esc_html_e( 'by profit: ', 'woo-calculate-your-price' ); ?><b id="pr_top1_item_profit_pro"></b></h4>
					<h2 id="pr_top_product_pro"></h2>	
					<span id="pr_top_product_sku_pro"></span><br/>
					<span><?php esc_html_e( 'quantity: ', 'woo-calculate-your-price' ); ?><b id="pr_top1_item_qty_pro"></b></span>
					<span><?php esc_html_e( 'sales: ', 'woo-calculate-your-price' ); ?><b id="pr_top1_sales_pro"></b></span><br/>
					<span><?php esc_html_e( 'total turnover (sales): ', 'woo-calculate-your-price' ); ?><b id="pr_top1_pro_turnover"></b></span><br/>
					<span><?php esc_html_e( 'total turnover (qty): ', 'woo-calculate-your-price' ); ?><b id="pr_top1_pro_turnover_qty"></b></span><br/>
					<span><?php esc_html_e( 'category: ', 'woo-calculate-your-price' ); ?><b id="pr_top1_cat_pro"></b></span>
				</div>
				<div class="cyp-total-item" style="border-right: 5px solid #B4B4B4">
					<h4><?php esc_html_e( '#2 PRODUCT ', 'woo-calculate-your-price' ); ?> 
						  <?php esc_html_e( 'by profit: ', 'woo-calculate-your-price' ); ?><b id="pr_top2_item_profit_pro"></b></h4>
					<h2 id="pr_top2_product_pro"></h2>	
					<span id="pr_top2_product_sku_pro"></span><br/>
					<span><?php esc_html_e( 'quantity: ', 'woo-calculate-your-price' ); ?><b id="pr_top2_item_qty_pro"></b></span>
					<span><?php esc_html_e( 'sales: ', 'woo-calculate-your-price' ); ?><b id="pr_top2_sales_pro"></b></span><br/>
					<span><?php esc_html_e( 'total turnover (sales): ', 'woo-calculate-your-price' ); ?><b id="pr_top2_pro_turnover"></b></span><br/>
					<span><?php esc_html_e( 'total turnover (qty): ', 'woo-calculate-your-price' ); ?><b id="pr_top2_pro_turnover_qty"></b></span><br/>
					<span><?php esc_html_e( 'category: ', 'woo-calculate-your-price' ); ?><b id="pr_top2_cat_pro"></b></span>	
				</div>
				<div class="cyp-total-item" style="border-right: 5px solid #b1d4ea;">
					<h2 id="pr_gross_sales">
					</h2>	
					<span><?php esc_html_e( 'net sales in this period', 'woo-calculate-your-price' ); ?></span>
				</div>
				<div class="cyp-total-item" style="border-right: 5px solid #b1d4ea;">
					<h2 id="pr_total_profit">
					</h2>	
					<span><?php esc_html_e( 'total profit in this period', 'woo-calculate-your-price' ); ?></span>
				</div>
				<div class="cyp-total-item" style="border-right: 5px solid #3498db;">
					<h2 id="pr_profit_percent">
					</h2>	
					<span><?php esc_html_e( 'profit this period', 'woo-calculate-your-price' ); ?></span>
				</div>
				<div class="cyp-total-item" style="border-right: 5px solid #dbe1e3;">
					<h2 id="pr_sum_orders">
					<?php echo esc_attr( number_format( (int) $orders->total, 0, $d_point, $t_sep ) ); ?>
					</h2>	
					<span><?php esc_html_e( 'orders placed', 'woo-calculate-your-price' ); ?></span>
				</div>
				<div class="cyp-total-item" style="border-right: 5px solid #dbe1e3;">
					<h2 id="pr_sum_items">
					</h2>	
					<span><?php esc_html_e( 'items purchased', 'woo-calculate-your-price' ); ?></span>
				</div>

			</div>
		</div>
		<?php
	}

	/**
	 * Get Orders table header
	 */
	public function cyp_rep_get_table_header() {
		?>
		<thead>
			<tr class="head-avr-back">
				<th class="head-avr" style="width: 85px;"><?php esc_html_e( 'Average', 'woo-calculate-your-price' ); ?></th>
				<th class="head-avr"></th>
				<th class="head-avr"></th>
				<th class="head-avr"></th>
				<th class="head-avr" style="width: 80px;"></th>
				<th class="head-avr cyp-center" id="o_avr_qty" style="width: 60px;"></th>
				<th class="head-avr cyp-right" id="o_avr_profit" style="width: 8%;"></th>
				<th class="head-avr cyp-right" id="o_avr_percent" style="width: 9%;"></th>
				<th class="head-avr cyp-right" id="o_avr_cost" style="width: 110px;"></th>
				<th class="head-avr cyp-right" id="o_avr_sale" style="width: 110px;"></th>
				<th class="head-avr cyp-right" id="o_avr_tax" style="width: 70px;"></th>
				<th class="head-avr cyp-right" id="o_avr_ship" style="width: 80px;"></th>
			</tr>
			<tr>
				<th><a href="#" onclick="sort(0,'number','r','table-report');"><?php esc_html_e( 'Order id', 'woo-calculate-your-price' ); ?></a> <i id="r0" class="fas fa-sort"></i></th>
				<th><a href="#" onclick="sort(1,'text','r','table-report');"><?php esc_html_e( 'Customer', 'woo-calculate-your-price' ); ?></a> <i id="r1" class="fas fa-sort"></i></th>
				<th><a href="#" onclick="sort(2,'text','r','table-report');"><?php esc_html_e( 'Role', 'woo-calculate-your-price' ); ?></a> <i id="r2" class="fas fa-sort"></i></th>
				<th><a href="#" onclick="sort(3,'date','r','table-report');"><?php esc_html_e( 'Date', 'woo-calculate-your-price' ); ?></a> <i id="r3" class="fas fa-sort"></i></th>
				<th><a href="#" onclick="sort(4,'text','r','table-report');"><?php esc_html_e( 'Status', 'woo-calculate-your-price' ); ?></a> <i id="r4" class="fas fa-sort"></i></th>
				<th class="cyp-center"><a href="#" onclick="sort(5,'number','r','table-report');"><?php esc_html_e( 'Items', 'woo-calculate-your-price' ); ?></a> <i id="r5" class="fas fa-sort"></i></th>
				<th class="cyp-right"><a href="#" onclick="sort(6,'number','r','table-report');"><?php esc_html_e( 'Profit', 'woo-calculate-your-price' ); ?></a> <i id="r6" class="fas fa-sort"></i></th>
				<th class="cyp-right"><a href="#" onclick="sort(7,'number','r','table-report');"><?php esc_html_e( 'Profit %', 'woo-calculate-your-price' ); ?></a> <i id="r7" class="fas fa-sort"></i></th>
				<th class="cyp-right"><a href="#" onclick="sort(8,'number','r','table-report');"><?php esc_html_e( 'Cost of goods', 'woo-calculate-your-price' ); ?></a> <i id="r8" class="fas fa-sort"></i></th>
				<th class="cyp-right"><a href="#" onclick="sort(9,'number','r','table-report');"><?php esc_html_e( 'Net sales', 'woo-calculate-your-price' ); ?></a> <i id="r9" class="fas fa-sort"></i></th>
				<th class="cyp-right"><a href="#" onclick="sort(10,'number','r','table-report');"><?php esc_html_e( 'Tax', 'woo-calculate-your-price' ); ?></a> <i id="r10" class="fas fa-sort"></i></th>
				<th class="cyp-right"><a href="#" onclick="sort(11,'number','r','table-report');"><?php esc_html_e( 'Shipping', 'woo-calculate-your-price' ); ?></a> <i id="r10" class="fas fa-sort"></i></th>
			</tr>
		</thead>
		<?php
	}

	/**
	 * Get customers table
	 */
	public function cyp_rep_get_customer_table() {

		$results     = $this->functions->cyp_get_product_report();
		$orders      = $results->orders;
		$cyp_options = get_option( 'cyp_options' );
		$date_format = get_option( 'date_format' );

		$this->cyp_rep_get_customer_table_head();

		foreach ( $orders as $order ) {

			//Do not include trash orders
			if ( 'trash' === $order->get_status() ) {
				continue;
			}
		
			$country = ( strlen( $order->get_billing_country() ) > 0 ) ? WC()->countries->countries[ $order->get_billing_country() ] : '';
			?>
			<tr class="lozad" data-exclude="">
				<td><a href="<?php echo esc_attr( admin_url( 'post.php?post=' . $order->get_id() . '&action=edit' ) ); ?>"><?php echo esc_attr( $order->get_id() ); ?></a></td>
				<td><?php echo esc_attr( date_format( new DateTime( $order->get_date_created() ), $date_format ) ); ?></td>
				<td><a href="<?php echo esc_attr( admin_url( 'user-edit.php?user_id=' ) . $order->get_customer_id() ); ?>"><?php echo esc_attr( $order->get_billing_first_name() ); ?></a></td>
				<td><a href="<?php echo esc_attr( admin_url( 'user-edit.php?user_id=' ) . $order->get_customer_id() ); ?>"><?php echo esc_attr( $order->get_billing_last_name() ); ?></a></td>
				<td><?php echo esc_attr( $order->get_billing_company() ); ?></td>
				<td><?php echo esc_attr( $order->get_billing_email() ); ?></td>
				<td><?php echo esc_attr( $order->get_billing_phone() ); ?></td>
				<td><?php echo esc_attr( $order->get_shipping_total() ); ?></td>
				<td><?php echo esc_attr( $order->get_total() ); ?></td>
				<td><?php echo esc_attr( $order->get_total_tax() ); ?></td>
				<td><?php echo esc_attr( $order->get_item_count() ); ?></td>
				<td style="font-size: 11px;"><?php echo esc_attr( $order->get_currency() ); ?></td>
				<td style="font-size: 11px;"><?php echo esc_attr( $country ); ?></td>
				<td style="font-size: 11px;"><?php echo esc_attr( $order->get_payment_method_title() ); ?></td>
			</tr>
			<?php
		}

		?>
		</tbody>
		<?php $this->cyp_rep_get_customer_table_footer(); ?>
		</table>
		<?php

	}

	/**
	 * Customer table head
	 */
	public function cyp_rep_get_customer_table_head() {
		?>
		<div style="display:block;height:10px;"></div>
		<table id="table-customers" class="wp-list-table widefat fixed striped posts" style="margin-top: 26px;">
		<thead>
			<tr>
				<th style="width:80px;"><a href="#" onclick="sort(0,'number','cc','table-customers');"><?php esc_attr_e( 'Order ID', 'woo-calculate-your-price' ); ?></a> <i id="cc0" class="fas fa-sort"></i></th>
				<th style="width:74px;"><a href="#" onclick="sort(1,'date','cc','table-customers');"><?php esc_attr_e( 'Date', 'woo-calculate-your-price' ); ?></a> <i id="cc1" class="fas fa-sort"></i></th>
				<th><a href="#" onclick="sort(2,'text','cc','table-customers');"><?php esc_attr_e( 'First name', 'woo-calculate-your-price' ); ?></a> <i id="cc2" class="fas fa-sort"></i></th>
				<th><a href="#" onclick="sort(3,'text','cc','table-customers');"><?php esc_attr_e( 'Last name', 'woo-calculate-your-price' ); ?></a> <i id="cc3" class="fas fa-sort"></i></th>
				<th style="width:180px;"><a href="#" onclick="sort(4,'text','cc','table-customers');"><?php esc_attr_e( 'Company', 'woo-calculate-your-price' ); ?></a> <i id="cc4" class="fas fa-sort"></i></th>
				<th style="width:180px;"><a href="#" onclick="sort(5,'text','cc','table-customers');"><?php esc_attr_e( 'E.mail', 'woo-calculate-your-price' ); ?></a> <i id="cc5" class="fas fa-sort"></i></th>
				<th><a href="#" onclick="sort(6,'number','cc','table-customers');"><?php esc_attr_e( 'Phone', 'woo-calculate-your-price' ); ?></a> <i id="cc6" class="fas fa-sort"></i></th>
				<th><a href="#" onclick="sort(7,'number','cc','table-customers');"><?php esc_attr_e( 'Shipping', 'woo-calculate-your-price' ); ?></a> <i id="cc7" class="fas fa-sort"></i></th>
				<th><a href="#" onclick="sort(8,'number','cc','table-customers');"><?php esc_attr_e( 'Total', 'woo-calculate-your-price' ); ?></a> <i id="cc8" class="fas fa-sort"></i></th>
				<th><a href="#" onclick="sort(9,'number','cc','table-customers');"><?php esc_attr_e( 'Tax', 'woo-calculate-your-price' ); ?></a> <i id="cc9" class="fas fa-sort"></i></th>
				<th style="width:50px;"><a href="#" onclick="sort(10,'number','cc','table-customers');"><?php esc_attr_e( 'Items', 'woo-calculate-your-price' ); ?></a> <i id="cc10" class="fas fa-sort"></i></th>
				<th style="width:80px;"><a href="#" onclick="sort(11,'text','cc','table-customers');"><?php esc_attr_e( 'Currency', 'woo-calculate-your-price' ); ?></a> <i id="cc11" class="fas fa-sort"></i></th>
				<th><a href="#" onclick="sort(12,'text','cc','table-customers');"><?php esc_attr_e( 'Country', 'woo-calculate-your-price' ); ?></a> <i id="cc12" class="fas fa-sort"></i></th>
				<th><a href="#" onclick="sort(13,'text','cc','table-customers');"><?php esc_attr_e( 'Payment', 'woo-calculate-your-price' ); ?></a> <i id="cc13" class="fas fa-sort"></i></th>
			</tr>
		</thead>
		<tbody>
		
		<?php
		
	}

	/**
	 * Get footer
	 */
	public function cyp_rep_get_customer_table_footer() {
		?>
		<tfoot>
			<tr>
				<td colspan="3" class="cyp-left" style="font-size: 11px;"><?php esc_attr_e( 'Totals', 'woo-calculate-your-price' ); ?></td>
				<td></td>
				<td></td>
				<td></td>
				<td></td>
				<td id="cf7" class="cyp-left" style="font-size: 11px;"></td>
				<td id="cf8" class="cyp-left" style="font-size: 11px;"></td>
				<td id="cf9" class="cyp-left" style="font-size: 11px;"></td>
				<td id="cf10" class="cyp-left" style="font-size: 11px;"></td>
				<td></td>
				<td></td>
				<td></td>
			</tr>
		</tfoot>
		<?php
	}

}


