<?php
/**
 * Cost & Reports Settings
 *
 * @package CostReports/Settings
 */

defined( 'ABSPATH' ) || exit;

/**
 * Settings for API.
 */
if ( class_exists( 'WC_Settings_CYP', false ) ) {
	return new WC_Settings_CYP();
}


/**
 * WC_Settings_CYP class
 */
class WC_Settings_CYP extends WC_Settings_Page {

	/**
	 * Constructor.
	 */
	public function __construct() {
		$this->id    = 'crw';
		$this->label = __( 'Cost & Reports', 'woo-calculate-your-price' );

		parent::__construct();
	
		register_setting( 'cyp_options_group', 'cyp_options_settings' );

	}

	/**
	 * Get sections
	 *
	 * @return array
	 */
	public function get_sections() {
	
		$sections = array(
			''       => __( 'General', 'woo-calculate-your-price' ),
			'second' => __( 'Integration', 'woo-calculate-your-price' ),
			'report' => __( 'Reports', 'woo-calculate-your-price' ),
		);
		
		return apply_filters( 'woocommerce_get_sections_' . $this->id, $sections );
	}

	/**
	 * Settings array
	 *
	 * @return array
	 */
	public function get_settings( $section = '' ) {

		global $current_section;
		$section  = $current_section;
		$settings = array();

		if ( '' === $section ) {

			$settings = array(

				array(
					'name' => __( 'Cost & Reports', 'woo-calculate-your-price' ),
					'type' => 'title',
					'desc' => __( 'The following options are used to configure Cost & Reports', 'woo-calculate-your-price' ),
					'id'   => 'cypsettings',
				),

				array(
					'name'     => __( 'Products per page', 'woo-calculate-your-price' ),
					'desc_tip' => __( 'Will create a paging function', 'woo-calculate-your-price' ),
					'id'       => 'cyp_options[cyp_posts_per_page]',
					'type'     => 'number',
					'css'      => 'min-width:200px;',
				),

				array(
					'name'     => __( 'Automatic stock management', 'woo-calculate-your-price' ),
					'desc_tip' => __( 'Turns of stock management when stock has null values, defaults sets status to: in stock', 'woo-calculate-your-price' ),
					'id'       => 'cyp_options[cyp_no_stock_management]',
					'type'     => 'checkbox',
					'css'      => 'min-width:200px;',
				),

				array(
					'name'     => __( 'Disable autofocus', 'woo-calculate-your-price' ),
					'desc_tip' => __( 'Disables autofocus on input fields and controls in table', 'woo-calculate-your-price' ),
					'id'       => 'cyp_options[cyp_no_autofocus]',
					'type'     => 'checkbox',
					'css'      => 'min-width:200px;',
				),

				array(
					'name'     => __( 'Hide ID and SKU', 'woo-calculate-your-price' ),
					'desc_tip' => __( 'Hides ID and SKU in the table below name', 'woo-calculate-your-price' ),
					'id'       => 'cyp_options[cyp_table_hide_id_sku]',
					'type'     => 'checkbox',
					'css'      => 'min-width:200px;',
				),

				array(
					'name'     => __( 'Other cost: name', 'woo-calculate-your-price' ),
					'desc_tip' => __( 'Default name is Other cost, keep name short', 'woo-calculate-your-price' ),
					'id'       => 'cyp_options[cyp_other_cost_name]',
					'type'     => 'text',
					'css'      => 'min-width:200px;',
				),

				array(
					'name'     => __( 'Shipping cost: name', 'woo-calculate-your-price' ),
					'desc_tip' => __( 'Default name is Shipping, keep name short', 'woo-calculate-your-price' ),
					'id'       => 'cyp_options[cyp_shipping_cost_name]',
					'type'     => 'text',
					'css'      => 'min-width:200px;',
				),

				array(
					'name'     => __( 'Show shipping cost', 'woo-calculate-your-price' ),
					'desc_tip' => __( 'Show shipping cost in the table', 'woo-calculate-your-price' ),
					'id'       => 'cyp_options[cyp_show_shipping_cost_tbl]',
					'type'     => 'checkbox',
					'css'      => 'min-width:200px;',
				),

				array(
					'type' => 'sectionend',
					'id'   => 'cyp_gen_settings',
				),
			);

		} elseif ( 'second' === $section ) {

			$settings = array(
				
				array(
					'name' => __( 'Cost & Reports', 'woo-calculate-your-price' ),
					'type' => 'title',
					'desc' => __( 'The following options are used to configure Cost & Reports', 'woo-calculate-your-price' ),
					'id'   => 'cypsettings',
				),

				array(
					'name'     => __( 'Hide purchase price', 'woo-calculate-your-price' ),
					'desc_tip' => __( 'Hide purchase price in edit product pages, often used with integrations', 'woo-calculate-your-price' ),
					'id'       => 'cyp_options[cyp_hide_purchase_price]',
					'type'     => 'checkbox',
					'css'      => 'min-width:200px;',
				),

				array(
					'name'     => __( 'Hide cost of goods', 'woo-calculate-your-price' ),
					'desc_tip' => __( 'Hide cost of goods in edit product pages, often used with integrations', 'woo-calculate-your-price' ),
					'id'       => 'cyp_options[cyp_hide_cost_of_goods]',
					'type'     => 'checkbox',
					'css'      => 'min-width:200px;',
				),

				array(
					'name'     => __( 'Purchase price field', 'woo-calculate-your-price' ),
					'desc_tip' => __( 'If integration with Purchase price field like: _purchase_price', 'woo-calculate-your-price' ),
					'id'       => 'cyp_options[cyp_purchase_price_field]',
					'type'     => 'text',
					'css'      => 'min-width:200px;',
				),

				array(
					'name'     => __( 'Cost of goods field', 'woo-calculate-your-price' ),
					'desc_tip' => __( 'If integration with Cost of goods field like: _cost_of_goods', 'woo-calculate-your-price' ),
					'id'       => 'cyp_options[cyp_cost_of_goods_field]',
					'type'     => 'text',
					'css'      => 'min-width:200px;',
				),
				
				array(
					'type' => 'sectionend',
					'id'   => 'cyp_integration_settings',
				),

			);
		} elseif ( 'report' === $section ) {

			$settings = array(
				
				array(
					'name' => __( 'Cost & Reports', 'woo-calculate-your-price' ),
					'type' => 'title',
					'desc' => __( 'The following options are used to configure Cost & Reports', 'woo-calculate-your-price' ),
					'id'   => 'cypsettings',
				),

				array(
					'name'     => __( 'Sales report per page', 'woo-calculate-your-price' ),
					'desc_tip' => __( 'Recomended to have this high', 'woo-calculate-your-price' ),
					'id'       => 'cyp_options[cyp_report_per_page]',
					'type'     => 'number',
					'css'      => 'min-width:200px;',
				),

				array(
					'name'     => __( 'Sales report CSV rows', 'woo-calculate-your-price' ),
					'desc_tip' => __( 'Set max rows to download', 'woo-calculate-your-price' ),
					'id'       => 'cyp_options[cyp_report_csv_max_count]',
					'type'     => 'number',
					'css'      => 'min-width:200px;',
				),

				array(
					'name'     => __( 'Good profit percent (above)', 'woo-calculate-your-price' ),
					'desc_tip' => __( 'Set from percent (marked green in reports)', 'woo-calculate-your-price' ),
					'id'       => 'cyp_options[cyp_good_profit_percent]',
					'type'     => 'number',
					'css'      => 'min-width:200px;',
				),

				array(
					'name'     => __( 'Bad profit percent (below)', 'woo-calculate-your-price' ),
					'desc_tip' => __( 'Set from percent and downwards (marked red in reports)', 'woo-calculate-your-price' ),
					'id'       => 'cyp_options[cyp_bad_profit_percent]',
					'type'     => 'number',
					'css'      => 'min-width:200px;',
				),

				array(
					'name'     => __( 'Refresh reports on new orders', 'woo-calculate-your-price' ),
					'desc_tip' => __( 'Automatically refresh order/product reports when new orders arrive', 'woo-calculate-your-price' ),
					'id'       => 'cyp_options[cyp_report_order_refresh]',
					'type'     => 'checkbox',
					'css'      => 'min-width:200px;',
				),


				array(
					'type' => 'sectionend',
					'id'   => 'cyp_report_settings',
				),
			);

		}

		return apply_filters( 'wc_' . $this->id . '_settings', $settings );

	}
	
}

return new WC_Settings_CYP();

