<?php
/**
 * Cost & Reports
 *
 * @package CostReports/includes
 */

defined( 'ABSPATH' ) || exit;

require_once __DIR__ . '/class-cyp-functions.php';
require_once __DIR__ . '/class-cyp-report.php';

class Cyp_Templates {

	/**
	 * Functions
	 */
	public $functions;

	/**
	 * Constructor
	 */
	public function __construct() {
		$this->functions = new Cyp_Functions();
	}


	/**
	 * Get view
	 */
	public function cyp_get_selected_view() {
		
		$view = ( strlen( filter_input( 1, 'view', FILTER_DEFAULT ) ) > 0 ) ? filter_input( 1, 'view', FILTER_DEFAULT ) : 'main';

		switch ( $view ) {
			case 'main':
				$this->cyp_get_main_page();
				break;
			case 'rep':
				$report_view = new Cyp_Report();
				$report_view->cyp_get_main_page();
				break;
		}
		
		$this->cyp_get_js_footer();
	}

	/**
	 * Get main page
	 */
	public function cyp_get_main_page() {
		?>
		<div class="cyp-main">
		<?php
		
		$this->cyp_get_top_header();
		$this->cyp_get_table_paging_top();
		$this->cyp_get_table();
		$this->cyp_get_sticky_footer();
		$this->cyp_get_foot();
		
	}
	
	/**
	 * Get foot
	 */
	public function cyp_get_foot() {
		$html = '';
		apply_filters( 'cyp_before_footer_close', $html );
		?>
		<div id="cyp-paging-bottom" class="div-paging" style="margin-top: 6px;">
		</div>
		</div>
		<?php
	}

	/**
	 * Get js footer
	 */
	public function cyp_get_js_footer() {
		
		$cyp_options    = get_option( 'cyp_options' );
		$default_markup = $cyp_options['cyp_default_markup'];
		$default_pages  = $cyp_options['cyp_posts_per_page'];
		$shipping_cost  = $cyp_options['cyp_show_shipping_cost_tbl'];
		$woo_point      = get_option( 'woocommerce_price_decimal_sep' );
		$woo_decimals   = get_option( 'woocommerce_price_num_decimals' );
		$view           = ( strlen ( filter_input( 1, 'view', FILTER_DEFAULT ) ) > 0 ) ? filter_input( 1, 'view', FILTER_DEFAULT ) : 'main';
		$tab_view       = ( strlen ( filter_input( 1, 'tab', FILTER_DEFAULT ) ) > 0 ) ? filter_input( 1, 'tab', FILTER_DEFAULT ) : 'orders';
		$hide_id_sku    = ( isset( $cyp_options['cyp_table_hide_id_sku'] ) && 'yes' === $cyp_options['cyp_table_hide_id_sku'] ) ? 'true' : 'false';

		$sum_col    = 11;
		$custom_col = '';
		
		if ( 'yes' === $shipping_cost ) {
			$sum_col = 12;
		}
		
		?>
		<script>
			var tbl               = '#cyptable';
			var tbl_rep           = '#table-report';
			var tbl_customers     = '#table-customers';
			var $                 = jQuery;
			var sum_col           = '<?php echo esc_js( $sum_col ); ?>';
			var default_markup    = '<?php echo esc_js( $default_markup ); ?>';
			var page_size         = '<?php echo esc_js( $default_pages ); ?>';
			var cyp_shipping_cost = '<?php echo esc_js( $shipping_cost ); ?>';
			var woo_decimals      = <?php echo esc_js( $woo_decimals ); ?>;
			var woo_point         = '<?php echo esc_js( $woo_point ); ?>';
			var view              = '<?php echo esc_js( $view ); ?>';
			var tab_view          = '<?php echo esc_js( $tab_view ); ?>';
			var hide_id_sku       = '<?php echo esc_js( $hide_id_sku ); ?>';
	
			jQuery(document).ready(function ( $ ) {
	
				var col = '';
				if(cyp_shipping_cost === 'yes'){
					col = 11;
				}
	
				if ( view === 'main' ) {
					$( tbl ).tableCalc({
						calcColumns: [ 2, 3, 4, 5, 6, 7, 8, 9, 10, col ], 
						calcColumn_sum: sum_col,
						rowId: 0, 
						textColumns: [ 1 ], 
						calcType: 'c', 
						calcCustom: '',
						decimals: 2, 
						calcOnLoad: false, 
						onEvent: '',
					});
					$( tbl +' tr td input' ).on( 'change', calcChanged );
					calcChanged( true );
	
					$( '#product_search' ).on( 'input', rowSearch );
					$( "input[name='stype']" ).on( 'click', radioChange );
	
					get_footer_totals();

				} else {
					if ( tab_view === 'customers' ) {
						$( tbl_customers ).tableCalc({
							calcColumns: [ 7, 8, 9, 10 ], 
							calcColumn_sum: 13,
							rowId: 0, 
							textColumns: [ 2, 3, 4, 5, 6, 11, 12, 13 ], 
							calcType: 'c', 
							calcCustom: '',
							decimals: 2, 
							calcOnLoad: false, 
							onEvent: '',
						});
					} else {
						$( tbl_rep ).tableCalc({
							calcColumns: [ 4, 5, 6, 7, 8 ], 
							calcColumn_sum: 8,
							rowId: 0, 
							textColumns: [ 1, 2, 3 ], 
							calcType: 'c', 
							calcCustom: '',
							decimals: 2, 
							calcOnLoad: false, 
							onEvent: '',
						});
					}

					switch( tab_view ) {
						case 'products':
							reportCalc();
							break;
						case 'orders':
							//Tbl header - Averages orders o_avr_tax
							$('#o_avr_qty').text( $(tbl_rep).tableCalc('getAverage', 5) );
							$('#o_avr_sale').text( $(tbl_rep).tableCalc('getAverage', 9) );
							$('#o_avr_profit').text( $(tbl_rep).tableCalc('getAverage', 6) );
							$('#o_avr_percent').text( $(tbl_rep).tableCalc('getAverage', 7) + '%' );
							$('#o_avr_cost').text( $(tbl_rep).tableCalc('getAverage', 8) );
							$('#o_avr_tax').text( $(tbl_rep).tableCalc('getAverage', 10) );
							$('#o_avr_ship').text( $(tbl_rep).tableCalc('getAverage', 11) );
							break;
						default:
							break;
					}

					
				}
				
				var observer = lozad(); // lazy loads elements
				observer.observe();
	
				$('#date_from,#date_to').datepicker();
				$('#date_from,#date_to').datepicker( 'option', 'dateFormat', 'yy-mm-dd' );

				//Before download
				$('#download_form').on('submit', beforeDownloadSubmit );
	
				//Count products
				if( view === 'main' ) {
					cypCountProducts(tbl);
				} else {
					if ( tab_view === 'customers') {
						cyp_rep_customers_set();
					} else {
						cypCountProducts(tbl_rep);
					}
					//Check for new orders
					cyp_check_new_orders();
				}

				//Hide ID and SKU
				if ( 'true' === hide_id_sku ) {
					$('#cyp-chk-hide-info').prop('checked',true);
				}

				<?php
				if ( 'main' === $view ) {
					?>
					// Add paging bottom
					$( '#cyp-paging-bottom' ).empty();
					$( '#cyp-paging-bottom' ).append( paging_buttons );
					<?php
				}
				?>
			});
	
		</script>
		<?php
	}

	/**
	 * Sticky footer
	 */
	public function cyp_get_sticky_footer() {
		
		$view = filter_input( 1, 'view', FILTER_DEFAULT );
		$page = filter_input( 1, 'page', FILTER_DEFAULT );
		
		if ( 'crw' === $page || 'main' === $view ) {
			?>
			<footer class="cyp-footer" style="display: flex;">
				<div style="flex: 0 0 37%;text-align:left;padding:4px;color:whitesmoke;">
				<?php 
				$img_file = plugins_url( '../consortia-100.png', __FILE__ );

				/* translators: %s: url to vendor and logo */ 
				printf( esc_html__( '- developed by %1$s%2$s%3$s', 'woo-calculate-your-price' ), '<a href="https://www.consortia.no/en/" target="_blank">', '<img src="' . esc_attr( $img_file ) . '" class="cas-logo">', '</a>' );
				?>
				</div>
				<div style="flex: 1;text-align:left;">
				<button class="button" id="reset-values-footer" onclick="cyp_reset_table_values();" style="width:150px;"><i class="fas fa-undo"></i> <?php esc_attr_e( 'Undo changes', 'woo-calculate-your-price' ); ?></button>
				<button type="button" id="saveall-foot" class="button action" onclick="saveAll();" style="width:150px;"><i class="fas fa-database"></i> <?php esc_html_e( 'Save all', 'woo-calculate-your-price' ); ?></button>
				</div>
			</footer>
			<?php
		}
	}

	/**
	 * Get header and search
	 */
	public function cyp_get_top_header() {

		$get_prod_search = filter_input( 1, 'product_search', FILTER_DEFAULT );
		$stype           = filter_input( 1, 'stype', FILTER_DEFAULT );
		$prod_cat        = filter_input( 1, 'product_cat', FILTER_DEFAULT );
		
		?>
		<div class="wrap">
			
			<div style="display: block;">
				<div style="width:50%;float:left;">
				<h1 class="wp-heading-inline"><?php esc_html_e( 'Cost & Reports', 'woo-calculate-your-price' ); ?></h1>
				</div>
				<div style="width:50%;float:right;text-align:right;padding-top:12px;">
				<i class="fas fa-info-circle" style="padding-left: 15px;"></i><span id="cyp-prod-count" style="padding-left:5px;"></span>
				</div>
			</div>
		</div>
		<div class="row-container">
			<div class="cyp-button-row">
			<?php $this->functions->cyp_get_view_buttons(); ?>
			</div>
			<div class="col-search display-desktop">
				<div>   
				<form name="gs" type="get" action="admin.php"> 
					<input type="hidden" name="page" value="crw"> 
					<input type="search" class="input-txt-search" onmouseover="<?php echo esc_js( $this->functions->cyp_get_autofocus_value( '' ) ); ?>" placeholder="<?php esc_html_e( 'search', 'woo-calculate-your-price' ); ?><?php echo ' ' . esc_attr( $get_prod_search ); ?>" id="product_search" name="product_search" >
					<button type="submit" id="btnsearch" class="button"><i class="fas fa-search"></i></button><br/>
					<div class="frm-radio">
					<?php esc_attr_e( 'Search in', 'woo-calculate-your-price' ); ?>
					<input type="radio" name="stype" value="s" <?php echo ( 's' === $stype ) ? 'checked="checked"' : ''; ?>><?php esc_attr_e( 'Text', 'woo-calculate-your-price' ); ?>
					<input type="radio" name="stype" value="sku" <?php echo ( 'sku' === $stype ) ? 'checked="checked"' : ''; ?>><?php esc_attr_e( 'SKU', 'woo-calculate-your-price' ); ?>
					<input type="radio" name="stype" value="rows" <?php echo ( 'rows' === $stype || !isset( $stype ) ) ? 'checked="checked"' : ''; ?>><?php esc_attr_e( 'Rows', 'woo-calculate-your-price' ); ?>
					</div>           
				</form>
				</div>
			</div>
		</div>
		<?php
	}

	/**
	 * Get table
	 */
	public function cyp_get_table() {
		?>
		<div class="display-desktop"> <!-- Table -->
			<table class="wp-list-table widefat fixed striped posts" id="cyptable" style="width:100%;">
				<thead>
					<?php $this->cyp_get_table_head(); ?>
				</thead>
				<tbody id="the-list">   
					<?php $this->functions->cyp_loop_products(); ?>
				</tbody>
					<?php $this->cyp_get_table_footer(); ?>
			</table>
			
		</div>
		
		<?php
	}


	/**
	 * Get paging above table
	 */
	public function cyp_get_table_paging_top() {

		$get_prod_cat = ( strlen( filter_input( 1, 'product_cat', FILTER_DEFAULT ) ) > 0 ) ? filter_input( 1, 'product_cat', FILTER_DEFAULT ) : get_option( 'cyp_options' )['cyp_product_cat'];
		$prod_search  = filter_input( 1, 'product_search', FILTER_DEFAULT );

		if ( strlen( $prod_search ) > 0 ) {
			$get_prod_cat = '';
		}
		
		?>
		<div class="row-cat-paging display-desktop">
			<div class="col-category"> <!-- Select category -->
				<?php $this->functions->cyp_get_categories_select( $get_prod_cat ); ?>
				
			<div class="col-clear"> 
			 
				<a href="#" class="button" id="a-delete-rows" onclick="deleteRows();"><i class="fas fa-trash-alt"></i> <?php esc_attr_e( 'Delete rows', 'woo-calculate-your-price' ); ?></a> 
				<a href="#" class="button" id="a-clear-calc" onclick="clearCalc();"><i class="fas fa-eraser"></i> <?php esc_attr_e( 'Clear calculations', 'woo-calculate-your-price' ); ?></a> 
				<button class="button" id="reset-values-footer" onclick="cyp_reset_table_values();" style="width:150px;"><i class="fas fa-undo"></i> <?php esc_attr_e( 'Undo changes', 'woo-calculate-your-price' ); ?></button>
	
			</div>
			</div>
			<div id="cyp-paging-top" class="div-paging">	
			</div>
			
		</div>
		<span class="cyp-saving" id="cyp-saving" style="max-width:100%;height:15px;margin-top:-12px;">
			<progress id="pbar-saving" class="pbar-saving" value="0" max="100" style="height: 14px;"></progress>
		</span>
		<?php
	}


	/**
	 * Get table head
	 */
	public function cyp_get_table_head() {
		
		?>
		<tr>
			<th class="th-first"><input type="checkbox" id="checkall" class="input-chk" onclick="cypCheckRows();"></th>
			<th style="width:20%;"><a href="#" onclick="sort(1,'text','s','cyptable');">
				<?php esc_html_e( 'Name', 'woo-calculate-your-price' ); ?></a> <i id="s1" class="fas fa-sort" style="padding-right: 5px;"></i> 
				<input type="checkbox" id="cyp-chk-hide-info" onclick="cyp_show_hide_info();"> <?php esc_html_e( 'Hide ID and SKU', 'woo-calculate-your-price' ); ?>
			</th>
			<th class="th-center"><a href="#" onclick="sort(2,'number','s','cyptable');"><?php esc_html_e( 'Purchase price', 'woo-calculate-your-price' ); ?></a> <i id="s2" class="fas fa-sort"></i> </th>
			<th class="th-center"><a href="#" onclick="sort(3,'number','s','cyptable');"><?php echo esc_attr( $this->functions->cyp_get_label_name( 'other_cost' ) ); ?></a> <i id="s3" class="fas fa-sort"></i> </th>
			<?php
			if ( $this->functions->cyp_show_shipping_cost() ) {
				?>
				<th class="th-center"><a href="#" onclick="sort(4,'number','s','cyptable');"><?php echo esc_attr( $this->functions->cyp_get_label_name( 'shipping_cost' ) ); ?></a> <i id="s4" class="fas fa-sort"></i> </th>
				<th class="th-center"><a href="#" onclick="sort(5,'number','s','cyptable');"><?php esc_html_e( 'Cost of goods', 'woo-calculate-your-price' ); ?></a> <i id="s5" class="fas fa-sort"></i> </th>
				<th class="th-center" style="width:6%;"><a href="#" onclick="sort(5,'number','s','cyptable');"><?php esc_html_e( 'Markup', 'woo-calculate-your-price' ); ?></a> <i id="s6" class="fas fa-sort"></i> </th>
				<th class="th-center"><a href="#" onclick="sort(7,'number','s','cyptable');"><?php esc_html_e( 'Price', 'woo-calculate-your-price' ); ?></a> <i id="s7" class="fas fa-sort"></i> </th>
				<th class="th-center"><a href="#" onclick="sort(8,'number','s','cyptable');"><?php esc_html_e( 'New price', 'woo-calculate-your-price' ); ?></a> <i id="s8" class="fas fa-sort"></i> </th>
				<th class="th-center" style="width:75px;"><a href="#" onclick="sort(9,'number','s','cyptable');"><?php esc_html_e( 'Stock', 'woo-calculate-your-price' ); ?></a> <i id="s9" class="fas fa-sort"></i> </th>
				<th class="th-center" style="width:7%;"><a href="#" onclick="sort(10,'number','s','cyptable');"><?php esc_html_e( 'Value at cost', 'woo-calculate-your-price' ); ?></a> <i id="s10" class="fas fa-sort"></i> </th>
				<th class="th-center"><a href="#" onclick="sort(11,'number','s','cyptable');"><?php esc_html_e( 'Retail value', 'woo-calculate-your-price' ); ?></a> <i id="s11" class="fas fa-sort"></i> </th>
				<th class="th-center"><a href="#" onclick="sort(12,'number','s','cyptable');"><?php esc_html_e( 'Profit', 'woo-calculate-your-price' ); ?></a> <i id="s12" class="fas fa-sort"></i> </th>
				<?php
			} else {
				?>
				<th class="th-center"><a href="#" onclick="sort(4,'number','s','cyptable');"><?php esc_html_e( 'Cost of goods', 'woo-calculate-your-price' ); ?></a> <i id="s4" class="fas fa-sort"></i> </th>
				<th class="th-center" style="width:6%;"><a href="#" onclick="sort(5,'number','s','cyptable');"><?php esc_html_e( 'Markup', 'woo-calculate-your-price' ); ?></a> <i id="s5" class="fas fa-sort"></i> </th>
				<th class="th-center"><a href="#" onclick="sort(6,'number','s','cyptable');"><?php esc_html_e( 'Price', 'woo-calculate-your-price' ); ?></a> <i id="s6" class="fas fa-sort"></i> </th>
				<th class="th-center"><a href="#" onclick="sort(7,'number','s','cyptable');"><?php esc_html_e( 'New price', 'woo-calculate-your-price' ); ?></a> <i id="s7" class="fas fa-sort"></i> </th>
				<th class="th-center"><a href="#" onclick="sort(8,'number','s','cyptable');"><?php esc_html_e( 'Stock', 'woo-calculate-your-price' ); ?></a> <i id="s8" class="fas fa-sort"></i> </th>
				<th class="th-center"><a href="#" onclick="sort(9,'number','s','cyptable');"><?php esc_html_e( 'Value at cost', 'woo-calculate-your-price' ); ?></a> <i id="s9" class="fas fa-sort"></i> </th>
				<th class="th-center"><a href="#" onclick="sort(10,'number','s','cyptable');"><?php esc_html_e( 'Retail value', 'woo-calculate-your-price' ); ?></a> <i id="s10" class="fas fa-sort"></i> </th>
				<th class="th-center"><a href="#" onclick="sort(11,'number','s','cyptable');"><?php esc_html_e( 'Profit', 'woo-calculate-your-price' ); ?></a> <i id="s11" class="fas fa-sort"></i> </th>
				<?php
			}
			?>
		</tr>
		<?php
			$this->cyp_get_table_head_info();
	}

	/**
	 * Get the js function for rows if shipping cost
	 *
	 * @param var $name name of field.
	 */
	public function cyp_get_js_calc_function( $name ) {
		$out = '';
		if ( $this->functions->cyp_show_shipping_cost() ) {
			switch ( $name ) {
				case 'cost_of_goods':
					$out = "calcSpecial(3,5,'cost_of_goods_select');";
					break;
				case 'markup':
					$out = "calcSpecial(4,6,'markup_select');";
					break;
				case 'new_price':
					$out = "calcSpecial(6,8,'new_price_select');";
					break;
				case 'stock':
					$out = "calcSpecial(7,9,'stock_select');";
					break;
			}
		} else {
			switch ( $name ) {
				case 'cost_of_goods':
					$out = "calcSpecial(2,4,'cost_of_goods_select');";
					break;
				case 'markup':
					$out = "calcSpecial(3,5,'markup_select');";
					break;
				case 'new_price':
					$out = "calcSpecial(5,7,'new_price_select');";
					break;
				case 'stock':
					$out = "calcSpecial(6,8,'stock_select');";
					break;
			}
		}
		return $out;
	}

	/**
	 * Get table head info
	 */
	public function cyp_get_table_head_info() {

		?>
			<tr class="th-info">
				<th></th>
				<th style="vertical-align: middle;"><strong><?php esc_html_e( 'Bulk Editor', 'woo-calculate-your-price' ); ?></strong><br /><span class="th-desc"><?php esc_html_e( 'Fill in values and/or select option to apply to all visible products', 'woo-calculate-your-price' ); ?></span></th>
				<th style="vertical-align: top;"><input type="number" name="purchase_price_select" id="purchase_price_select" class="input-txt" onmouseover="<?php echo esc_js( $this->functions->cyp_get_autofocus_value( '' ) ); ?>"><br/>
					<select name="purchase_price_select_type" id="purchase_price_select_type" class="input-select" onchange="calcSpecial(0,2,'purchase_price_select');">
						<?php $this->cyp_get_bulk_options( '' ); ?>
					</select>
				</th>
				<th style="vertical-align: top;"><input type="number" name="other_cost_select" id="other_cost_select" class="input-txt" onmouseover="<?php echo esc_js( $this->functions->cyp_get_autofocus_value( '' ) ); ?>">
				<br/>
					<select name="other_cost_select_type" id="other_cost_select_type" class="input-select" onchange="calcSpecial(1,3,'other_cost_select');">
						<?php $this->cyp_get_bulk_options( 'other_cost' ); ?>
					</select>
				</th>
				<?php
				if ( $this->functions->cyp_show_shipping_cost() ) {
					?>
					<th style="vertical-align: top;"><input type="number" name="shipping_cost_select" id="shipping_cost_select" class="input-txt" onmouseover="<?php echo esc_js( $this->functions->cyp_get_autofocus_value( '' ) ); ?>">
					<br/>
						<select name="shipping_cost_select_type" id="shipping_cost_select_type" class="input-select" onchange="calcSpecial(2,4,'shipping_cost_select');">
							<?php $this->cyp_get_bulk_options( 'shipping' ); ?>
						</select>
					</th>
					<?php
				}
				?>
				<th style="vertical-align: top;"><input type="number" name="cost_of_goods_select" id="cost_of_goods_select" class="input-txt" onmouseover="<?php echo esc_js( $this->functions->cyp_get_autofocus_value( '' ) ); ?>">
				<br/>
					<select name="cost_of_goods_select_type" id="cost_of_goods_select_type" class="input-select" onchange="<?php echo esc_attr( $this->cyp_get_js_calc_function( 'cost_of_goods' ) ); ?>">
						<?php $this->cyp_get_bulk_options( 'cost_of_goods' ); ?>
					</select>
				</th>
				<th style="vertical-align: top;"><input type="number" name="markup_select" id="markup_select" class="input-txt" onmouseover="<?php echo esc_js( $this->functions->cyp_get_autofocus_value( '' ) ); ?>">
				<br/>
					<select name="markup_select_type" id="markup_select_type" class="input-select" onchange="<?php echo esc_attr( $this->cyp_get_js_calc_function( 'markup' ) ); ?>">
						<?php $this->cyp_get_bulk_options( 'markup' ); ?>
					</select>
				</th>
				<th style="vertical-align:bottom;text-align:center;padding-top:16px;font-size:.7rem;">
					<select name="current_price_select_type" id="current_price_select_type" class="input-select" onchange="cyp_change_vat_price(this);">
						<?php $this->cyp_get_bulk_options( 'current_price' ); ?>
					</select>
				</th>
				<th style="vertical-align: top;"><input type="number" name="new_price_select" id="new_price_select" class="input-txt" onmouseover="<?php echo esc_js( $this->functions->cyp_get_autofocus_value( '' ) ); ?>">
				<br/>
					<select name="new_price_select_type" id="new_price_select_type" class="input-select" onchange="<?php echo esc_attr( $this->cyp_get_js_calc_function( 'new_price' ) ); ?>">
						<?php $this->cyp_get_bulk_options( 'new_price' ); ?>
					</select>
				</th>

				<th style="vertical-align: top;"><input type="number" name="stock_select" id="stock_select" class="input-txt" onmouseover="<?php echo esc_js( $this->functions->cyp_get_autofocus_value( '' ) ); ?>">
				<br/>
					<select name="stock_select_type" id="stock_select_type" class="input-select" onchange="<?php echo esc_attr( $this->cyp_get_js_calc_function( 'stock' ) ); ?>">
						<?php $this->cyp_get_bulk_options( 'stock' ); ?>
					</select>
				</th>
				<th colspan="3" style="vertical-align: top;text-align:center;">
					<input type="checkbox" id="exclude_price_save"> <?php esc_html_e( 'Exclude price on save', 'woo-calculate-your-price' ); ?>
					<button type="button" id="saveall" class="button action" onclick='saveAll();' style="width:100%;max-width:180px;margin-left:5px;">
						<i class="fas fa-database"></i> <?php esc_html_e( 'Save all', 'woo-calculate-your-price' ); ?>
					</button>
					<!--div class="cyp-saving" id="cyp-saving">
						<progress id="pbar-saving" class="pbar-saving" value="0" max="100"></progress>
					</div-->
				</th>
			</tr>

		<?php
	}

	/**
	 * Get options for bulk functions
	 *
	 * @param var $type type of select.
	 */
	public function cyp_get_bulk_options( $type ) {

		$option_blank              = __( 'Select', 'woo-calculate-your-price' );
		$option_increase           = __( 'Increase', 'woo-calculate-your-price' );
		$option_increase_percent   = __( 'Increase in %', 'woo-calculate-your-price' );
		$option_increase_number    = __( 'Increase fixed amount', 'woo-calculate-your-price' );
		$option_decrease           = __( 'Decrease', 'woo-calculate-your-price' );
		$option_decrease_percent   = __( 'Decrease in %', 'woo-calculate-your-price' );
		$option_decrease_number    = __( 'Decrease fixed amount', 'woo-calculate-your-price' );
		$option_set_fixed          = __( 'Set fixed', 'woo-calculate-your-price' );
		$option_set_fixed_markup   = __( 'Set fixed %', 'woo-calculate-your-price' );
		$option_set_fixed_number   = __( 'Set fixed amount', 'woo-calculate-your-price' );
		$option_round_up           = __( 'Round upwards', 'woo-calculate-your-price' );
		$option_round_down         = __( 'Round downwards', 'woo-calculate-your-price' );
		$option_round_two          = __( 'Round two decimals', 'woo-calculate-your-price' );
		$option_copy_price         = __( 'Copy current price', 'woo-calculate-your-price' );
		$option_copy_purchase      = __( 'Copy purchase price', 'woo-calculate-your-price' );
		$purchase_increase_percent = __( 'Plus % of purchase price', 'woo-calculate-your-price' );
		$purchase_plus_percent     = __( 'Purchase price plus %', 'woo-calculate-your-price' );
		$option_inc_vat            = __( 'Regular price inc.VAT (dynamic)', 'woo-calculate-your-price' );
		$option_ex_vat             = __( 'Regular price ex.VAT (default)', 'woo-calculate-your-price' );
		$option_cur_inc_vat        = __( 'Current price inc.VAT', 'woo-calculate-your-price' );
		$option_cur_ex_vat         = __( 'Current price ex.VAT', 'woo-calculate-your-price' );


		if ( 'stock' === $type ) {
			?>
				<option value="0" selected="selected"><?php echo esc_html( $option_blank ); ?></option>
				<option value="up_n"><?php echo esc_html( $option_increase ); ?></option>
				<option value="down_n"><?php echo esc_html( $option_decrease ); ?></option>
				<option value="fix_n"><?php echo esc_html( $option_set_fixed ); ?></option>
			<?php
		} elseif ( 'markup' === $type ) {
			?>
				<option value="0" selected="selected"><?php echo esc_html( $option_blank ); ?></option>
				<option value="fix_n"><?php echo esc_html( $option_set_fixed_markup ); ?></option>
				<option value="up_n"><?php echo esc_html( $option_increase ); ?> %</option>
				<option value="down_n"><?php echo esc_html( $option_decrease ); ?> %</option>
			<?php
		} elseif ( 'new_price' === $type ) {
			?>
				<option value="0" selected="selected"><?php echo esc_html( $option_blank ); ?></option>
				<option value="up_p"><?php echo esc_html( $option_increase_percent ); ?></option>
				<option value="up_n"><?php echo esc_html( $option_increase_number ); ?></option>
				<option value="down_p"><?php echo esc_html( $option_decrease_percent ); ?></option>
				<option value="down_n"><?php echo esc_html( $option_decrease_number ); ?></option>
				<option value="fix_n"><?php echo esc_html( $option_set_fixed_number ); ?></option>
				<option value="round_up"><?php echo esc_html( $option_round_up ); ?></option>
				<option value="round_down"><?php echo esc_html( $option_round_down ); ?></option>
				<option value="round_two"><?php echo esc_html( $option_round_two ); ?></option>
				<option value="copy_price"><?php echo esc_html( $option_copy_price ); ?></option>
			<?php
		} elseif ( 'cost_of_goods' === $type ) {
			?>
				<option value="0" selected="selected"><?php echo esc_html( $option_blank ); ?></option>
				<option value="up_p"><?php echo esc_html( $option_increase_percent ); ?></option>
				<option value="purchase_plus_percent"><?php echo esc_html( $purchase_plus_percent ); ?></option>
				<option value="up_n"><?php echo esc_html( $option_increase_number ); ?></option>
				<option value="down_p"><?php echo esc_html( $option_decrease_percent ); ?></option>
				<option value="down_n"><?php echo esc_html( $option_decrease_number ); ?></option>
				<option value="fix_n"><?php echo esc_html( $option_set_fixed_number ); ?></option>
				<option value="round_up"><?php echo esc_html( $option_round_up ); ?></option>
				<option value="round_down"><?php echo esc_html( $option_round_down ); ?></option>
				<option value="round_two"><?php echo esc_html( $option_round_two ); ?></option>
				<option value="copy_purchase"><?php echo esc_html( $option_copy_purchase ); ?></option>
			<?php
		} elseif ( 'other_cost' === $type || 'shipping' === $type ) {
			?>
				<option value="0" selected="selected"><?php echo esc_html( $option_blank ); ?></option>
				<option value="up_p"><?php echo esc_html( $option_increase_percent ); ?></option>
				<option value="percent_purchase"><?php echo esc_html( $purchase_increase_percent ); ?></option>
				<option value="up_n"><?php echo esc_html( $option_increase_number ); ?></option>
				<option value="down_p"><?php echo esc_html( $option_decrease_percent ); ?></option>
				<option value="down_n"><?php echo esc_html( $option_decrease_number ); ?></option>
				<option value="fix_n"><?php echo esc_html( $option_set_fixed_number ); ?></option>
				<option value="round_up"><?php echo esc_html( $option_round_up ); ?></option>
				<option value="round_down"><?php echo esc_html( $option_round_down ); ?></option>
				<option value="round_two"><?php echo esc_html( $option_round_two ); ?></option>	
			<?php
		} elseif ( 'current_price' === $type ) {
			?>
				<option value="0" selected="selected"><?php echo esc_html( $option_blank ); ?></option>
				<option value="inc_vat"><?php echo esc_html( $option_inc_vat ); ?></option>
				<option value="ex_vat"><?php echo esc_html( $option_ex_vat ); ?></option>
				<option value="cur_inc_vat"><?php echo esc_html( $option_cur_inc_vat ); ?></option>
				<option value="cur_ex_vat"><?php echo esc_html( $option_cur_ex_vat ); ?></option>
			<?php
		} else {
			?>
				<option value="0" selected="selected"><?php echo esc_html( $option_blank ); ?></option>
				<option value="up_p"><?php echo esc_html( $option_increase_percent ); ?></option>
				<option value="up_n"><?php echo esc_html( $option_increase_number ); ?></option>
				<option value="down_p"><?php echo esc_html( $option_decrease_percent ); ?></option>
				<option value="down_n"><?php echo esc_html( $option_decrease_number ); ?></option>
				<option value="fix_n"><?php echo esc_html( $option_set_fixed_number ); ?></option>
				<option value="round_up"><?php echo esc_html( $option_round_up ); ?></option>
				<option value="round_down"><?php echo esc_html( $option_round_down ); ?></option>
				<option value="round_two"><?php echo esc_html( $option_round_two ); ?></option>
			<?php
		}

	}

	/**
	 * Get table row
	 *
	 * @param var $product object.
	 * @param var $date_format string.
	 * @param var $has_attributes bool.
	 * @param var $parent_id int.
	 */
	public function cyp_get_table_row( $product, $has_attributes, $parent_id ) {
		
		$product_name   = $product->get_title();
		$product_id     = $product->get_id();
		$cyp_options    = get_option( 'cyp_options' );
		$cost_of_goods  = ( $cyp_options['cyp_cost_of_goods_field'] ) ? $cyp_options['cyp_cost_of_goods_field'] : '_cost_of_goods';
		$purchase_price = ( $cyp_options['cyp_purchase_price_field'] ) ? $cyp_options['cyp_purchase_price_field'] : '_purchase_price';
		$hide_id_sku    = ( isset( $cyp_options['cyp_table_hide_id_sku'] ) && 'yes' === $cyp_options['cyp_table_hide_id_sku'] ) ? true : false;

		if ( $has_attributes ) {

			$product_name = $this->functions->cyp_get_product_name( $product );
			$product_id   = $product->get_parent_id();
			
			if ( 0 === $product_id ) {
				$product_id = $product->get_id();
			}

		}

		$tax_rate  = '';
		$tax_rates = WC_Tax::get_rates( $product->get_tax_class() );

		foreach ( $tax_rates as $value ) {
			$tax_rate = $value['rate'];
		}

		?>
		<tr class="lozad" data-exclude="" style="vertical-align: top;">
			<td id="<?php echo esc_attr( $product->get_id() ); ?>" style="padding-top:10px;">
				<form id="frm_<?php echo esc_attr( $product->get_id() ); ?>_<?php echo esc_attr( wp_rand( 1, 50000 ) ); ?>" method="post">
				<input name="id" value="<?php echo esc_attr( $product->get_id() ); ?>" type="checkbox" class="input-chk">
			</td>
			<td style="display:flex;width:98%">
				<?php
				if ( ! $has_attributes ) {
					?>
					<div style="flex:1;width:100%;">
					<input type="text" class="input-name" name="product_name" value="<?php echo esc_html( $product_name ); ?>" onmouseover="<?php echo esc_js( $this->functions->cyp_get_autofocus_value( '' ) ); ?>;">
					<input type="hidden" name="name_update" value="true">
					<?php
				} else {
					?>
					<div style="flex:1;width:100%;padding-top:5px;">
					<input type="hidden" name="product_name" value="<?php echo esc_html( $product_name ); ?>">
					<input type="hidden" name="name_update" value="false">
					<?php echo esc_html( $product_name ); ?>
					<?php
				}
				?>
					<ul class="cyp-ul-info<?php echo esc_attr( ( $hide_id_sku ) ? '-hide' : '' ); ?>" id="cyp_ul_<?php echo esc_attr( $product->get_id() ); ?>">
						<li><?php esc_html_e( 'ID:', 'woo-calculate-your-price' ); ?> <?php echo esc_attr( $product->get_id() ); ?></li>
						<li><?php esc_html_e( 'SKU:', 'woo-calculate-your-price' ); ?> <?php echo esc_attr( $product->get_sku() ); ?></li>
					</ul>
				</div>
				<div style="flex: 0;text-align:center;">
					<a href="<?php echo esc_url( get_admin_url() . 'post.php?post=' . $product_id . '&action=edit' ); ?>">
					<i class="fas fa-edit"></i></a>
				</div>
			</td>
			<td>
				<input type="number" name="purchase_price" onchange="doCalc(this);" class="input-txt" value="<?php echo esc_attr( $this->functions->cyp_string_to_float( get_post_meta( $product->get_id(), $purchase_price, true ) ) ); ?>" onmouseover="<?php echo esc_js( $this->functions->cyp_get_autofocus_value( '' ) ); ?>">
			</td>
			<td>
				<input type="number" name="other_cost" onchange="doCalc(this);" class="input-txt" value="<?php echo esc_attr( get_post_meta( $product->get_id(), '_other_cost', true ) ); ?>" onmouseover="<?php echo esc_js( $this->functions->cyp_get_autofocus_value( '' ) ); ?>">
			</td>
			<?php
			if ( $this->functions->cyp_show_shipping_cost() ) {
				?>
				<td>
				<input type="number" name="shipping_cost" onchange="doCalc(this);" class="input-txt" value="<?php echo esc_attr( get_post_meta( $product->get_id(), '_cyp_shipping_cost', true ) ); ?>" onmouseover="<?php echo esc_js( $this->functions->cyp_get_autofocus_value( '' ) ); ?>">
				</td>
				<?php
			}
			?>
			<td>
				<input type="number" name="cost_of_goods" onchange="doCalc(this);" class="input-txt" value="<?php echo esc_attr( $this->functions->cyp_string_to_float( get_post_meta( $product->get_id(), $cost_of_goods, true ) ) ); ?>" onmouseover="<?php echo esc_js( $this->functions->cyp_get_autofocus_value( '' ) ); ?>">
			</td>
			<td>
				<input type="number" name="markup" onchange="doCalc(this);" class="input-txt" value="<?php echo esc_attr( get_post_meta( $product->get_id(), '_markup_percent', true ) ); ?>" onmouseover="<?php echo esc_js( $this->functions->cyp_get_autofocus_value( '' ) ); ?>">
			</td>
			<td>
				<input type="hidden" name="price_inc_vat" value="<?php echo esc_attr( wc_get_price_including_tax( $product, array( 'qty' => 1, 'price' => $product->get_regular_price() ) ) ); ?>">
				<input type="hidden" name="price_ex_vat" value="<?php echo esc_attr( wc_get_price_excluding_tax( $product, array( 'qty' => 1, 'price' => $product->get_regular_price() ) ) ); ?>">
				<input type="hidden" name="cur_price_ex_vat" value="<?php echo esc_attr( wc_get_price_excluding_tax( $product, array( 'qty' => 1, 'price' => $product->get_price() ) ) ); ?>">
				<input type="hidden" name="cur_price_inc_vat" value="<?php echo esc_attr( wc_get_price_including_tax( $product, array( 'qty' => 1, 'price' => $product->get_price() ) ) ); ?>">
				<input type="hidden" name="tax_rate" value="<?php echo esc_attr( $tax_rate ); ?>">
				<input type="number" step="any" name="price" readonly="readonly" class="input-txt <?php echo esc_attr( ( $product->get_sale_price() > 0 ) ? 'cyp-onsale' : '' ); ?>" value="<?php echo esc_attr( $product->get_regular_price() ); ?>"> 
			</td> 
			<td>
				<input type="number" step="any" name="price_new" onchange="doCalc(this);" class="input-txt" value="" onmouseover="<?php echo esc_js( $this->functions->cyp_get_autofocus_value( 'new_price' ) ); ?>"> 
			</td> 
			<td>
				<input type="number" name="stock" onchange="doCalc(this);" class="input-txt" value="<?php echo esc_attr( $product->get_stock_quantity() ); ?>" onmouseover="<?php echo esc_js( $this->functions->cyp_get_autofocus_value( 'stock' ) ); ?>;"> 
			</td>   
			<td>
				<input type="number" name="stock-value-cost" class="input-txt" value="" readonly="readonly" style="direction:rtl;">
			</td>
			<td>
				<input type="number" name="sales-value" class="input-txt" value="" readonly="readonly" style="direction:rtl;">
			</td>
			<td>
				<input type="number" name="margin" class="input-txt" value="" readonly="readonly" style="direction:rtl;"> 
				</form>
			</td>
		</tr>
		<?php
	}


	/**
	 * Get table footer
	 */
	public function cyp_get_table_footer() {
		
		$colspan_val   = 10;
		$shipping_cost = false;
		
		if ( $this->functions->cyp_show_shipping_cost() ) {
			$colspan_val   = 11;
			$shipping_cost = true;
		}

		?>
		<tfoot>
			<tr>
				<td><?php wp_nonce_field( 'footer_id' ); ?></td>
				<td><input type="hidden" id="msg-confirm-delete" value="<?php esc_attr_e( 'Move checked items to trash?', 'woo-calculate-your-price' ); ?>"></td>
				<td></td>
				<td></td>
				<?php 
				if ( $shipping_cost ) {
					?>
					<td></td>
					<?php
				}
				?>
				<td></td>
				<td></td>
				<td></td>
				<td></td>
				<td><span id="tbl-total-s" class="span-txt-center"></span></td>
				<td><span id="tbl-total-sc" class="span-txt"></span></td>
				<td><span id="tbl-total-sv" class="span-txt"></span></td>
				<td><span id="tbl-total-m" class="span-txt"></span></td>
			</tr>
			<tr class="th-info">
				<td colspan="<?php echo esc_attr( $colspan_val ); ?>"></td>
				<td colspan="2">
				<button type="button" id="saveall_foot" class="button action" onclick='saveAll();' style="width:100%;">
					<i class="fas fa-database"></i> <?php esc_html_e( 'Save all', 'woo-calculate-your-price' ); ?>
				</button>
				</td>
			</tr>
		</tfoot>
		<?php
	}

	

}


