<?php
/**
 * Cost & Reports
 *
 * @package CostReports/includes
 */

defined( 'ABSPATH' ) || exit;

require_once dirname( __FILE__ ) . '/class-cyp-functions.php';

if ( ! class_exists( 'Cyp_Woo') ) {

	class Cyp_Woo {


		/**
		 * Admin hooks
		 */
		public static function cyp_admin_hooks() {
			
			add_action( 'woocommerce_product_options_general_product_data', array( __CLASS__, 'cyp_add_product_options_pricing' ) );
			add_action( 'admin_notices', array( __CLASS__, 'cyp_admin_activation_notice_success' ) );
			add_action( 'woocommerce_process_product_meta_simple', array( __CLASS__, 'cyp_save_product_meta_fields' ) );
			add_filter( 'woocommerce_order_item_display_meta_key', array( __CLASS__, 'cyp_set_custom_order_display_name_callback' ) );
			add_filter( 'admin_footer_text', array( __CLASS__, 'cyp_set_footer_text' ) );
			
			//CYP
			add_action( 'cyp_action_cyp_create_link_to_wbte', array( __CLASS__, 'cyp_create_link_to_wbte' ) );

			//Add settings
			self::cyp_add_language_support();

			//Add settings
			add_filter( 'woocommerce_get_settings_pages', array( __CLASS__, 'cyp_add_settings' ) );

		}

		/**
		 * Add settings and language support
		 */
		public static function cyp_add_language_support() {

			load_plugin_textdomain( 'woo-calculate-your-price', false, basename( dirname( __FILE__ ) ) . '/languages' );

		}

		/**
		 * Add settings and language support
		 */
		public static function cyp_add_settings( $settings ) {

			$settings[] = include_once dirname( __FILE__ ) . '../../includes/class-cyp-settings.php';
			return $settings;

		}

		/**
		 * Add extra pricing fields
		 */
		public static function cyp_add_product_options_pricing() {

			$cyp_options         = get_option( 'cyp_options' );
			$hide_purchase_price = $cyp_options['cyp_hide_purchase_price'] ? $cyp_options['cyp_hide_purchase_price'] : 'no';
			$hide_cost_of_goods  = $cyp_options['cyp_hide_cost_of_goods'] ? $cyp_options['cyp_hide_cost_of_goods'] : 'no';
			
			if ( 'no' === $hide_purchase_price ) {
				woocommerce_wp_text_input(
					array(
						'id'                => '_purchase_price',
						'class'             => 'wc_input_price',
						'label'             => __( 'Purchase price', 'woo-calculate-your-price' ),
						'type'              => 'text',
					)
				);
			} else {
				woocommerce_wp_hidden_input(
					array(
						'id'                => '_purchase_price',
						'label'             => __( 'Purchase price', 'woo-calculate-your-price' ),
						'type'              => 'number',
						'custom_attributes' => array(
							'step' 	=> 'any',
							'min'	=> '0',
							) 
					)
				);
			}

			woocommerce_wp_hidden_input(
				array(
					'id'        => '_cyp_shipping_cost',
					'label'     => __( 'Shipping cost', 'woo-calculate-your-price' ),
					'type'      => 'number',
				)
			);

			woocommerce_wp_hidden_input(
				array(
					'id'        => '_other_cost',
					'label'     => __( 'Other cost', 'woo-calculate-your-price' ),
					'type'      => 'number',
				)
			);

			if ( 'no' === $hide_cost_of_goods ) {
				woocommerce_wp_text_input(
					array(
						'id'        => '_cost_of_goods',
						'class'     => 'wc_input_price',
						'label'     => __( 'Cost of goods', 'woo-calculate-your-price' ),
						'type'      => 'text',
					)
				);
			} else {
				woocommerce_wp_hidden_input(
					array(
						'id'        => '_cost_of_goods',
						'label'     => __( 'Cost of goods', 'woo-calculate-your-price' ),
						'type'      => 'number',
					)
				);
			}

			woocommerce_wp_hidden_input(
				array(
					'id'                => '_markup_percent',
					'label'             => __( 'Markup', 'woo-calculate-your-price' ),
					'type'              => 'number',
					'custom_attributes' => array(
						'step' 	=> 'any',
						'min'	=> '0',
						) 
				)
			);
		}

		/**
		 * On activation notice
		 */
		public static function cyp_admin_activation_notice_success() {

			$allowed_tags = array(
				'a' => array(
					'class'  => array(),
					'href'   => array(),
					'target' => array(),
					'title'  => array(),
				),
			);

			/* translators: %s: url for documentation */
			$read_doc = __( 'Read the <a href="%1$s" target="_blank"> extension documentation </a> for more information.', 'woo-calculate-your-price' );
			$out_str  = sprintf( $read_doc, esc_url( 'https://docs.woocommerce.com/document/cost-reports-woocommerce' ) );

			if ( get_transient( 'cyp-admin-notice-activated' ) ) {
				?>
				<div class="updated woocommerce-message">
					<a class="woocommerce-message-close notice-dismiss" href="<?php echo esc_url( wp_nonce_url( add_query_arg( 'wc-hide-notice', 'cyp_admin_activation_notice_success' ), 'woocommerce_hide_notices_nonce', '_wc_notice_nonce' ) ); ?>"><?php esc_html_e( 'Dismiss', 'woo-calculate-your-price' ); ?></a>
					<p>
						<?php esc_html_e( 'Thank you for installing Cost & Reports for WooCommerce. You can now start using the extension. ', 'woo-calculate-your-price' ); ?>
						<?php echo wp_kses( $out_str, $allowed_tags ); ?>
					</p>
					<p class="submit">
						<a href="<?php echo esc_url( admin_url( 'admin.php?page=crw' ) ); ?>" class="button-primary"><?php esc_html_e( 'Start Cost & Reports', 'woo-calculate-your-price' ); ?></a>
						<a href="<?php echo esc_url( admin_url( 'admin.php?page=wc-settings&tab=crw' ) ); ?>" class="button-secondary"><?php esc_html_e( 'Settings', 'woo-calculate-your-price' ); ?></a>
					</p>
				</div>

				<?php
				delete_transient( 'cyp-admin-notice-activated' );
			}
		}

		/**
		 * Save custom fields to Products.
		 *
		 * @param var $product_id product id.
		 */
		public static function cyp_save_product_meta_fields( $product_id ) {
			
			$nonce = isset( $_REQUEST['woocommerce_meta_nonce'] ) ? sanitize_text_field( $_REQUEST['woocommerce_meta_nonce'] ) : ''; // @codingStandardsIgnoreLine.
			if ( ! wp_verify_nonce( $nonce, 'woocommerce_save_data' ) ) { 
				return;
			}

			$cyp_options    = get_option( 'cyp_options' );
			$cog_field      = ( $cyp_options['cyp_cost_of_goods_field'] ) ? $cyp_options['cyp_cost_of_goods_field'] : '_cost_of_goods';
			$product        = wc_get_product( $product_id );
			$cost_of_goods  = isset( $_POST['_cost_of_goods'] ) ? sanitize_text_field( $_POST['_cost_of_goods'] ) : '';
			$purchase_price = isset( $_POST['_purchase_price'] ) ? sanitize_text_field( $_POST['_purchase_price'] ) : '';
			$shipping_cost  = isset( $_POST['_cyp_shipping_cost'] ) ? sanitize_text_field( $_POST['_cyp_shipping_cost'] ) : '';

			if ( $cost_of_goods && '_cost_of_goods' === $cog_field ) {
				$product->update_meta_data( '_cost_of_goods', $cost_of_goods );
			}

			if ( isset( $purchase_price ) ) {
				$product->update_meta_data( '_purchase_price', $purchase_price );	
			}

			if ( isset( $shipping_cost ) ) {
				$product->update_meta_data( '_cyp_shipping_cost', $shipping_cost );	
			}

			$product->save();

		}

		/**
		 * Set display name for COG and purchase price
		 */
		public static function cyp_set_custom_order_display_name_callback( $display_key ) {

			
			if ( is_admin() ) {

				if ( '_cost_of_goods' === $display_key ) {
					return __( 'Cost of goods', 'woo-calculate-your-price' );
				}

				if ( '_purchase_price' === $display_key ) {
					return __( 'Purchase price', 'woo-calculate-your-price' );
				}
				
			}
			
			return $display_key;
		}

		/**
		 * Set footer text.
		 */
		public static function cyp_set_footer_text( $text ) {

			$page = filter_input( 1, 'page', FILTER_DEFAULT );

			if ( 'crw' === $page ) {
				$img_file = plugins_url( '../consortia-100.png', __FILE__ );

				/* translators: %s: url to vendor and logo */ 
				printf( esc_html__( '- developed by %1$s%2$s%3$s', 'woo-calculate-your-price' ), '<a href="https://www.consortia.no/en/" target="_blank">', '<img src="' . esc_attr( $img_file ) . '" class="cas-logo">', '</a>' );
			
			} else {

				return $text;

			}

		}

		/** 
		 * If Bulk Table Editor is present create link
		 */
		public static function cyp_create_link_to_wbte() {

			if ( is_plugin_active( 'woo-bulk-table-editor/woo-bulk-table-editor.php' ) ) {
				$p_cat = filter_input( 1, 'product_cat', FILTER_DEFAULT );
				?>
				<a href="<?php echo esc_url( admin_url( 'edit.php?post_type=product&page=wbte-products&product_cat=' . $p_cat ) ); ?>" class="button" id="wbte">
					<i class="fas fa-tags"></i> <?php esc_attr_e( 'Bulk Table Editor', 'woo-calculate-your-price' ); ?></a>
				<?php
			}

		}


	}
	
	Cyp_Woo::cyp_admin_hooks();

}
