<?php
/**
 * Cost & Reports
 *
 * @package CostReports
 *
 * Plugin Name: Cost & Reports for WooCommerce
 * Plugin URI: https://woocommerce.com/products/cost-reports-woocommerce/
 * Description: Add cost, cost of goods, Markup, create prices and view profit, order and sales reports.
 * Version: 3.1.1
 * Author: 20script
 * Author URI: http://www.20script.ir
 * Text Domain: woo-calculate-your-price
 * Domain Path: /languages
 *
 * Tested up to: 6.1.1
 * Woo: 5672510:32940bdd46501b19a59c2ac13602345f
 * WC requires at least: 3.3
 * WC tested up to: 7.4.0
 *
 * Copyright: © 2018-2023 Consortia AS.
 * License: GNU General Public License v3.0
 * License URI: http://www.gnu.org/licenses/gpl-3.0.html
 */

global $cyp_version;
$cyp_version = '3.1.1';

add_action( 'before_woocommerce_init', function() {
	if ( class_exists( '\Automattic\WooCommerce\Utilities\FeaturesUtil' ) ) {
		\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', __FILE__, true );
	}
} );

register_activation_hook( __FILE__, 'cyp_install' );
register_deactivation_hook( __FILE__, 'cyp_deactivate' );

use Automattic\WooCommerce\Admin\Features\Navigation\Menu;
use Automattic\WooCommerce\Admin\Features\Navigation\Screen;

add_action( 'admin_menu', 'cyp_woocommerce_submenu_page' );

require_once dirname( __FILE__ ) . '/includes/class-cyp-woo.php';

/**
 * Install
 */
function cyp_install() {

	global $wp_version;

	if ( version_compare( $wp_version, '4.1', '<' ) ) {
		wp_die( 'This plugin require WordPress 4.1 or higher.' );
	}

	$cyp_options_arr = array(
		'cyp_posts_per_page'         => '150',
		'cyp_product_cat'            => '',
		'cyp_autosort'               => '',
		'cyp_default_markup'         => '',
		'cyp_hide_purchase_price'    => '',
		'cyp_hide_cost_of_goods'     => '',
		'cyp_no_stock_management'    => '',
		'cyp_no_autofocus'           => '',
		'cyp_cost_of_goods_field'    => '',
		'cyp_purchase_price_field'   => '',
		'cyp_other_cost_name'        => '',
		'cyp_shipping_cost_field'    => '',
		'cyp_shipping_cost_name'     => '',
		'cyp_hide_shipping_cost'     => '',
		'cyp_show_shipping_cost_tbl' => '',
		'cyp_report_per_page'        => '300',
		'cyp_report_csv_max_count'   => '5000',
		'cyp_good_profit_percent'    => '50',
		'cyp_bad_profit_percent'     => '20',
		'cyp_report_order_refresh'   => '',
		'cyp_table_hide_id_sku'      => '',
	);

	update_option( 'cyp_options', $cyp_options_arr );

	set_transient( 'cyp-admin-notice-activated', true );

	flush_rewrite_rules();
}

/**
 * Deactivate
 *
 * @return void
 */
function cyp_deactivate() {

	flush_rewrite_rules();
}

/**
 * Create submenu in products
 */
function cyp_woocommerce_submenu_page() {

	add_submenu_page(
		'woocommerce',
		__( 'Cost & Reports', 'woo-calculate-your-price' ),
		__( 'Cost & Reports', 'woo-calculate-your-price' ),
		'manage_woocommerce',
		'crw',
		'cyp_products_page',
		30
	);

	if (
		! class_exists( '\Automattic\WooCommerce\Admin\Features\Navigation\Menu' ) ||
		! class_exists( '\Automattic\WooCommerce\Admin\Features\Navigation\Screen' )
	) {
		return;
	}

	Menu::add_plugin_item(
		array(
			'id'         => 'woo-calculate-your-price',
			'title'      => __( 'Cost & Reports', 'woo-calculate-your-price' ),
			'capability' => 'manage_woocommerce',
			'url'        => 'crw',
		)
	);

}

/**
 * Get Bulk Table Editor main page
 */
function cyp_products_page() {

	if ( class_exists( 'WooCommerce' ) ) {
		do_action( 'cyp_action_get_main_page' );
	}

}

/**
 * Get the main page
 */
function cyp_get_main_page() {

	if ( class_exists( 'WooCommerce' ) ) {

		include_once dirname( __FILE__ ) . '/includes/class-cyp-templates.php';
		global $cyp_templates;
		$cyp_templates = new Cyp_Templates();
		$cyp_templates->cyp_get_selected_view();

	}

}
add_action( 'cyp_action_get_main_page', 'cyp_get_main_page' );

/**
 * Add scripts and style
 *
 * @param var $hook object.
 */
function cyp_header_scripts( $hook ) {
	
	if ( 'woocommerce_page_crw' !== $hook ) {
		return;
	}

	global $cyp_version;
	
	wp_register_script( 'cyp_jquery-ui', 'https://code.jquery.com/ui/1.13.1/jquery-ui.js', array( 'jquery' ), '1.13.1', true );
	wp_enqueue_script( 'cyp_jquery-ui' );

	wp_register_script( 'cyp_tablecalc', plugins_url( '/assets/js/jquery.tablecalc.min.js', __FILE__ ), array( 'jquery' ), $cyp_version, false );
	wp_enqueue_script( 'cyp_tablecalc' );

	wp_register_script( 'cyp_scripts', plugins_url( '/assets/js/cyp-scripts.js', __FILE__ ), array( 'jquery' ), $cyp_version, true );
		
	wp_register_script( 'lozad', 'https://cdn.jsdelivr.net/npm/lozad/dist/lozad.min.js', array(), '1', false );
	wp_enqueue_script( 'lozad' );

	wp_register_script( 'exportjs', 'https://cdn.jsdelivr.net/npm/@linways/table-to-excel@1.0.4/dist/tableToExcel.min.js', array(), '1', false );
	wp_enqueue_script( 'exportjs' );

	wp_register_style( 'woocommerce_admin', plugins_url( '../plugins/woocommerce/assets/css/admin.css' ), array(), '1.12.1' );
	wp_enqueue_style( 'woocommerce_admin' );

	wp_register_style( 'fonta', 'https://use.fontawesome.com/releases/v5.2.0/css/all.css', array(), $cyp_version );
	wp_enqueue_style( 'fonta' );

	wp_register_style( 'jquery-ui', 'https://code.jquery.com/ui/1.13.1/themes/base/jquery-ui.css', array(), '1.13.1', 'all' );
	wp_enqueue_style( 'jquery-ui' );

	wp_register_style( 'cyp_css', plugins_url( '/assets/css/cyp.css', __FILE__ ), array(), $cyp_version );
	wp_enqueue_style( 'cyp_css' );

	// Localize the script with new data
	$translation = array(
		'products'   => __( 'Products', 'woo-calculate-your-price' ),
		'variations' => __( 'Variations', 'woo-calculate-your-price' ),
	);
	wp_localize_script( 'cyp_scripts', 'cyp_object', $translation );
	wp_enqueue_script( 'cyp_scripts' );

}
add_action( 'admin_enqueue_scripts', 'cyp_header_scripts' );


/**
 * Update product (ajax)
 */
function cyp_update_table_rows_ajax_handler() {
	
	check_ajax_referer( 'footer_id', 'nonce' );
	$data = wp_unslash( $_POST );

	cyp_update_table_rows_data( $data );

	delete_transient( 'cyp_json_products' );

	die();
}
add_action( 'wp_ajax_cyp_update_table_rows_data', 'cyp_update_table_rows_ajax_handler' );
add_action( 'wp_ajax_nopriv_cyp_update_table_rows_data', 'cyp_update_table_rows_ajax_handler' );

/**
 * Update products
 * 
 * @param var $data data.
 */
function cyp_update_table_rows_data( $data ) {

	include_once dirname( __FILE__ ) . '/includes/class-cyp-functions.php';
	$functions = new Cyp_Functions();
	
	foreach ( (array) $data['rows'] as $row ) {
		$functions->cyp_update_product( $row );
	}
	
}
add_action( 'cyp_update_table_rows_data_async', 'cyp_update_table_rows_data', 5 );

/**
 * Check for new orders
 */
function cyp_check_for_new_orders() {

	check_ajax_referer( 'footer_id', 'nonce' );
	$data = wp_unslash( $_POST );
	
	$current_new_orders = wc_processing_order_count();

	echo wp_kses( strval( $current_new_orders ), 'post' );
	
	die();

}
add_action( 'wp_ajax_cyp_check_for_new_orders', 'cyp_check_for_new_orders' );
add_action( 'wp_ajax_nopriv_cyp_check_for_new_orders', 'cyp_check_for_new_orders' );

/**
 * Create csv file
 */
function cyp_create_csv_file() {

	include_once dirname( __FILE__ ) . '/includes/class-cyp-functions.php';
	$functions = new Cyp_Functions();

	$functions->cyp_create_csv_export_file();

}
add_action( 'admin_post_return_csv_file', 'cyp_create_csv_file' );

/**
 * Create csv file
 */
function cyp_create_report_csv_file() {

	include_once dirname( __FILE__ ) . '/includes/class-cyp-functions.php';
	$functions = new Cyp_Functions();

	$functions->cyp_create_report_csv_export_file();

}
add_action( 'admin_post_return_report_csv_file', 'cyp_create_report_csv_file' );

/**
 * Delete product (ajax)
 */
function cyp_delete_table_rows_ajax_handler() {
	
	check_ajax_referer( 'footer_id', 'nonce' );
	$data = wp_unslash( $_POST );

	cyp_delete_table_rows_data( $data );

	delete_transient( 'cyp_json_products' );

	die();

}
add_action( 'wp_ajax_cyp_delete_table_rows_data', 'cyp_delete_table_rows_ajax_handler' );
add_action( 'wp_ajax_nopriv_cyp_delete_table_rows_data', 'cyp_delete_table_rows_ajax_handler' );

/**
 * Delete products
 * 
 * @param var $data data.
 */
function cyp_delete_table_rows_data( $data ) {

	include_once dirname( __FILE__ ) . '/includes/class-cyp-functions.php';
	$functions = new Cyp_Functions();

	foreach ( (array) $data['rows'] as $row ) {
		$functions->cyp_move_to_trash( $row );
	}

}
add_action( 'cyp_delete_table_rows_data_async', 'cyp_delete_table_rows_data' );

/**
 * Notice - success
 */
function cyp_admin_notice_message_success( $message ) {
	?>
		<div class="notice notice-success is-dismissible">
			<p><?php echo esc_attr( $message ); ?></p>
		</div>
	<?php
}
add_action( 'admin_notices_message_success', 'cyp_admin_notice_message_success' );

/**
 * Add COG and purchase price to order line on checkout
 */
function cyp_create_order_line_item( $item, $cart_item_key, $values, $order ) {

	$cyp_options          = get_option( 'cyp_options' );	
	$cost_of_goods_field  = ( $cyp_options['cyp_cost_of_goods_field'] ) ? $cyp_options['cyp_cost_of_goods_field'] : '_cost_of_goods';
	$purchase_price_field = ( $cyp_options['cyp_purchase_price_field'] ) ? $cyp_options['cyp_purchase_price_field'] : '_purchase_price';
	$product_id           = ( $item->get_variation_id() > 0 ) ? $item->get_variation_id() : $item->get_product_id();
	$cost_of_goods        = get_post_meta( $product_id, $cost_of_goods_field, true );
	$purchase_price       = get_post_meta( $product_id, $purchase_price_field, true );
	
	if ( ! empty( $cost_of_goods ) ) {
		$item->update_meta_data( '_cost_of_goods', $cost_of_goods );
	}

	if ( ! empty( $purchase_price ) ) {
		$item->update_meta_data( '_purchase_price', $purchase_price );
	}

	return $item;

}
add_filter( 'woocommerce_checkout_create_order_line_item', 'cyp_create_order_line_item', 90, 4 );

/**
 * Order items (admin) - set meta on variations
 */
function cyp_woocommerce_admin_order_item_values( $product, $item, $item_id ) {

	if ( is_null( $product ) || ! $item->is_type( 'line_item' ) || ! is_a( $product, 'WC_Product' ) ) {
		return;
	}

	$cyp_options    = get_option( 'cyp_options' );	
	$cost_of_goods  = ( $cyp_options['cyp_cost_of_goods_field'] ) ? $cyp_options['cyp_cost_of_goods_field'] : '_cost_of_goods';
	$purchase_price = ( $cyp_options['cyp_purchase_price_field'] ) ? $cyp_options['cyp_purchase_price_field'] : '_purchase_price';

	if ( $product && $product->is_type( 'variable' ) || $product->is_type( 'variation' ) ) {
		
		$cog_value = get_post_meta( $product->get_id(), $cost_of_goods, true );
		$pp_value  = get_post_meta( $product->get_id(), $purchase_price, true );

		if ( ! empty( $cog_value ) && empty( $item->get_meta( $cost_of_goods ) ) ) {
			wc_add_order_item_meta( $item_id, $cost_of_goods, $cog_value );
		}

		if ( ! empty( $pp_value ) && empty( $item->get_meta( $purchase_price ) ) ) {
			wc_add_order_item_meta( $item_id, $purchase_price, $pp_value );
		}
	
	}

}
add_filter('woocommerce_admin_order_item_values', 'cyp_woocommerce_admin_order_item_values', 10, 3 );

/**
 * Add COG and purchase price to new or existing orders in admin
 */
function cyp_add_order_meta_for_line_item( $item_id, $item, $order_id ) {

	if ( is_admin() ) {

		$cyp_options          = get_option( 'cyp_options' );	
		$cost_of_goods_field  = ( $cyp_options['cyp_cost_of_goods_field'] ) ? $cyp_options['cyp_cost_of_goods_field'] : '_cost_of_goods';
		$purchase_price_field = ( $cyp_options['cyp_purchase_price_field'] ) ? $cyp_options['cyp_purchase_price_field'] : '_purchase_price';
		$wc_o_item            = new WC_Order_Item_Product( $item_id );
		$product_id           = $wc_o_item->get_product_id();
		$cost_of_goods        = get_post_meta( $product_id, $cost_of_goods_field, true );
		$purchase_price       = get_post_meta( $product_id, $purchase_price_field, true );

		if ( ! empty( $cost_of_goods ) ) {
			wc_add_order_item_meta( $item_id, '_cost_of_goods', $cost_of_goods );	
		}

		if ( ! empty( $purchase_price ) ) {
			wc_add_order_item_meta( $item_id, '_purchase_price', $purchase_price );
		}
	}

}
add_action( 'woocommerce_new_order_item', 'cyp_add_order_meta_for_line_item', 10, 3 );

/**
 * Add custom product variation fields.
 *
 * @param var $loop loop var.
 * @param var $variation_data data.
 * @param var $variation variation.
 */
function cyp_add_product_variation_options_pricing( $loop, $variation_data, $variation  ) {

	$cyp_options         = get_option( 'cyp_options' );
	$hide_purchase_price = $cyp_options['cyp_hide_purchase_price'] ? $cyp_options['cyp_hide_purchase_price'] : 'no';
	$hide_cost_of_goods  = $cyp_options['cyp_hide_cost_of_goods'] ? $cyp_options['cyp_hide_cost_of_goods'] : 'no';

	if ( 'no' === $hide_purchase_price ) {
		woocommerce_wp_text_input(
			array(
				'id'       => '_purchase_price[' . $variation->ID . ']',
				'class'    => 'wc_input_price',
				'label'    => __( 'Purchase price', 'woo-calculate-your-price' ),
				'type'     => 'text',
				'value'    => get_post_meta( $variation->ID, '_purchase_price', true ),
			)
		);
	} else {
		woocommerce_wp_hidden_input(
			array(
				'id'      => '_purchase_price[' . $variation->ID . ']',
				'label'   => __( 'Purchase price', 'woo-calculate-your-price' ),
				'type'    => 'number',
				'value'   => get_post_meta( $variation->ID, '_purchase_price', true ),
			)
		);
	}

	woocommerce_wp_hidden_input(
		array(
			'id'        => '_cyp_shipping_cost[' . $variation->ID . ']',
			'label'     => __( 'Shipping cost', 'woo-calculate-your-price' ),
			'type'      => 'number',
			'value'     => get_post_meta( $variation->ID, '_cyp_shipping_cost', true ),
		)
	);

	woocommerce_wp_hidden_input(
		array(
			'id'        => '_other_cost[' . $variation->ID . ']',
			'label'     => __( 'Other cost', 'woo-calculate-your-price' ),
			'type'      => 'number',
			'value'     => get_post_meta( $variation->ID, '_other_cost', true ),
		)
	);

	if ( 'no' === $hide_cost_of_goods ) {
		woocommerce_wp_text_input(
			array(
				'id'        => '_cost_of_goods[' . $variation->ID . ']',
				'class'     => 'wc_input_price',
				'label'     => __( 'Cost of goods', 'woo-calculate-your-price' ),
				'type'      => 'text',
				'value'     => get_post_meta( $variation->ID, '_cost_of_goods', true ),
			)
		);
	} else {
		woocommerce_wp_hidden_input(
			array(
				'id'        => '_cost_of_goods[' . $variation->ID . ']',
				'label'     => __( 'Cost of goods', 'woo-calculate-your-price' ),
				'type'      => 'number',
				'value'     => get_post_meta( $variation->ID, '_cost_of_goods', true ),
			)
		);
	}

	woocommerce_wp_hidden_input(
		array(
			'id'      => '_markup_percent[' . $variation->ID . ']',
			'label'   => __( 'Markup', 'woo-calculate-your-price' ),
			'type'    => 'number',
			'value'   => get_post_meta( $variation->ID, '_markup_percent', true ),
		)
	);
}
add_action( 'woocommerce_product_after_variable_attributes', 'cyp_add_product_variation_options_pricing', 10, 3 );

/**
 * Save custom fields to product variations.
 *
 * @param var $variation_id variation id.
 * @param var $i iteration.
 */
function cyp_save_product_variation_meta( $variation_id, $i ) {

	check_ajax_referer( 'save-variations', 'security' );
	
	$data = wp_unslash( $_POST );

	if ( ! empty( $data['_purchase_price'][ $variation_id ] ) ) {
		update_post_meta( $variation_id, '_purchase_price', esc_attr( $data['_purchase_price'][ $variation_id ] ) );
	}
	
	if ( ! empty( $data['_cost_of_goods'][ $variation_id ] ) ) {
		update_post_meta( $variation_id, '_cost_of_goods', esc_attr( $data['_cost_of_goods'][ $variation_id ] ) );
	}

	if ( ! empty( $data['_cyp_shipping_cost'][ $variation_id ] ) ) {
		update_post_meta( $variation_id, '_cyp_shipping_cost', esc_attr( $data['_cyp_shipping_cost'][ $variation_id ] ) );
	}

	delete_transient( 'cyp_json_products' );

}
add_action( 'woocommerce_save_product_variation', 'cyp_save_product_variation_meta', 20, 2 );

